@@ -35,17 +35,48 @@
 void FillLensProjectionList(wxControlWithItems* list)
 {
     list->Clear();
-    list->Append(_("Normal (rectilinear)"),(void*)HuginBase::SrcPanoImage::RECTILINEAR);
-    list->Append(_("Panoramic (cylindrical)"),(void*)HuginBase::SrcPanoImage::PANORAMIC);
-    list->Append(_("Circular fisheye"),(void*)HuginBase::SrcPanoImage::CIRCULAR_FISHEYE);
-    list->Append(_("Full frame fisheye"),(void*)HuginBase::SrcPanoImage::FULL_FRAME_FISHEYE);
-    list->Append(_("Equirectangular"),(void*)HuginBase::SrcPanoImage::EQUIRECTANGULAR);
-    list->Append(_("Orthographic"),(void*)HuginBase::SrcPanoImage::FISHEYE_ORTHOGRAPHIC);
-    list->Append(_("Stereographic"),(void*)HuginBase::SrcPanoImage::FISHEYE_STEREOGRAPHIC);
-    list->Append(_("Equisolid"),(void*)HuginBase::SrcPanoImage::FISHEYE_EQUISOLID);
-    list->Append(_("Fisheye Thoby"),(void*)HuginBase::SrcPanoImage::FISHEYE_THOBY);
+    HuginLensTools::LensInfoVector lensInfoVector(GetLensProjectionList());
+    for (auto& lensInfo : lensInfoVector)
+    {
+        list->Append(lensInfo.name, (void*)lensInfo.id);
+    };
     list->SetSelection(0);
-};
+}
+WXIMPEX HuginLensTools::LensInfoVector GetLensProjectionList()
+{
+    // add all lens types to vector
+    HuginLensTools::LensInfo lensInfo;
+    HuginLensTools::LensInfoVector lensInfoVector;;
+    lensInfo.id = HuginBase::SrcPanoImage::RECTILINEAR;
+    lensInfo.name = _("Normal (rectilinear)");
+    lensInfoVector.push_back(lensInfo);
+    lensInfo.id = HuginBase::SrcPanoImage::PANORAMIC;
+    lensInfo.name = _("Panoramic (cylindrical)");
+    lensInfoVector.push_back(lensInfo);
+    lensInfo.id = HuginBase::SrcPanoImage::CIRCULAR_FISHEYE;
+    lensInfo.name = _("Circular fisheye");
+    lensInfoVector.push_back(lensInfo);
+    lensInfo.id = HuginBase::SrcPanoImage::FULL_FRAME_FISHEYE;
+    lensInfo.name = _("Full frame fisheye");
+    lensInfoVector.push_back(lensInfo);
+    lensInfo.id = HuginBase::SrcPanoImage::EQUIRECTANGULAR;
+    lensInfo.name = _("Equirectangular");
+    lensInfoVector.push_back(lensInfo);
+    lensInfo.id = HuginBase::SrcPanoImage::FISHEYE_ORTHOGRAPHIC;
+    lensInfo.name = _("Orthographic");
+    lensInfoVector.push_back(lensInfo);
+    lensInfo.id = HuginBase::SrcPanoImage::FISHEYE_STEREOGRAPHIC;
+    lensInfo.name = _("Stereographic");
+    lensInfoVector.push_back(lensInfo);
+    lensInfo.id = HuginBase::SrcPanoImage::FISHEYE_EQUISOLID;
+    lensInfo.name = _("Equisolid");
+    lensInfoVector.push_back(lensInfo);
+    lensInfo.id = HuginBase::SrcPanoImage::FISHEYE_THOBY;
+    lensInfo.name = _("Fisheye Thoby");
+    lensInfoVector.push_back(lensInfo);
+    return lensInfoVector;
+}
+;
 
 void FillBlenderList(wxControlWithItems* list)
 {
@@ -430,10 +461,10 @@ bool CheckLensStacks(HuginBase::Panorama* pano, bool allowCancel)
                 const HuginBase::SrcPanoImage& image2 = pano->getImage(j);
                 if (image1.YawisLinkedWith(image2))
                 {
-                    stacksCorrectLinked = stacksCorrectLinked &
-                        image1.HFOVisLinkedWith(image2) &
-                        image1.RadialDistortionisLinkedWith(image2) &
-                        image1.RadialDistortionCenterShiftisLinkedWith(image2) &
+                    stacksCorrectLinked = stacksCorrectLinked &&
+                        image1.HFOVisLinkedWith(image2) &&
+                        image1.RadialDistortionisLinkedWith(image2) &&
+                        image1.RadialDistortionCenterShiftisLinkedWith(image2) &&
                         image1.ShearisLinkedWith(image2);
                 };
             };
