@@ -31,6 +31,21 @@
 // functions to handle with default project/output filenames
 typedef std::map<wxString, wxString> Placeholdersmap;
 
+wxString CleanDateTime(const wxString& input)
+{
+    // replace invalid characters in format string
+    // which are not allowed in filenames
+    wxString result(input);
+    result.Replace("/", "_");
+    result.Replace("\\", "_");
+    result.Replace(":", "-");
+    result.Replace("*", ".");
+    result.Replace("?", ".");
+    result.Replace("<", ".");
+    result.Replace(">", ".");
+    result.Replace("|", ".");
+    return result;
+}
 void FillDefaultPlaceholders(Placeholdersmap & placeholder)
 {
     placeholder[wxT("%firstimage")]=_("first image");
@@ -40,8 +55,8 @@ void FillDefaultPlaceholders(Placeholdersmap & placeholder)
     placeholder[wxT("%projection")]=_("Equirectangular");
     placeholder[wxT("%focallength")]=wxT("28");
     wxDateTime datetime=wxDateTime(13,wxDateTime::May,2012,11,35);
-    placeholder[wxT("%date")]=datetime.FormatDate();
-    placeholder[wxT("%time")]=datetime.FormatTime();
+    placeholder[wxT("%date")] = CleanDateTime(datetime.FormatDate());
+    placeholder[wxT("%time")] = CleanDateTime(datetime.FormatTime());
     placeholder[wxT("%maker")]=_("Camera maker");
     placeholder[wxT("%model")]=_("Camera model");
     placeholder[wxT("%lens")]=_("Lens");
@@ -52,17 +67,30 @@ void FillPlaceholders(Placeholdersmap & placeholder, const HuginBase::Panorama &
     const HuginBase::SrcPanoImage & img0=pano.getImage(0);
     wxFileName firstImg(wxString(img0.getFilename().c_str(),HUGIN_CONV_FILENAME));
     placeholder[wxT("%firstimage")]=firstImg.GetName();
-    if(firstImg.GetDirCount()>0)
+    if (firstImg.GetDirCount() > 0)
     {
-        placeholder[wxT("%directory")]=firstImg.GetDirs().Last();
+        placeholder[wxT("%directory")] = firstImg.GetDirs().Last();
+    }
+    else
+    {
+        placeholder[wxT("%directory")] = wxEmptyString;
     };
     placeholder[wxT("%focallength")]=wxString::Format(wxT("%.0f"), img0.getExifFocalLength());
     struct tm exifdatetime;
-    if(img0.getExifDateTime(&exifdatetime)==0)
+    if (img0.getExifDateTime(&exifdatetime) == 0)
     {
-        wxDateTime datetime=wxDateTime(exifdatetime);
-        placeholder[wxT("%date")]=datetime.FormatDate();
-        placeholder[wxT("%time")]=datetime.FormatTime();
+        wxDateTime datetime = wxDateTime(exifdatetime);
+        placeholder[wxT("%date")] = CleanDateTime(datetime.FormatDate());
+        placeholder[wxT("%time")] = CleanDateTime(datetime.FormatTime());
+    }
+    else
+    {
+        // no date found, use file create date 
+        const wxFileName firstFile(img0.getFilename());
+        wxDateTime createTime;
+        firstFile.GetTimes(NULL, NULL, &createTime);
+        placeholder[wxT("%date")] = CleanDateTime(createTime.FormatDate());
+        placeholder[wxT("%time")] = CleanDateTime(createTime.FormatTime());
     };
     placeholder[wxT("%maker")]=wxString(img0.getExifMake().c_str(), wxConvLocal);
     placeholder[wxT("%model")]=wxString(img0.getExifModel().c_str(), wxConvLocal);
