@@ -129,7 +129,11 @@ AboutDialog::AboutDialog(wxWindow *parent)
 #endif
 
     // set the position and the size (x,y,width,height). -1 = keep existing
-    SetSize(1,1,560,560);
+#if wxCHECK_VERSION(3,1,0)
+    SetSize(this->FromDIP(wxSize(560, 560)));
+#else
+    SetSize(1, 1, 560, 560);
+#endif
     CenterOnParent();
 }
 
