@@ -29,6 +29,7 @@
 
 #include <panotools/PanoToolsInterface.h>
 #include <base_wx/wxImageCache.h>
+#include <wx/overlay.h>
 
 class CPEditorPanel;
 class CPImageCtrl;
@@ -40,7 +41,7 @@ class CPEvent : public wxCommandEvent
 {
     DECLARE_DYNAMIC_CLASS(CPEvent)
 
-    enum CPEventMode { NONE, NEW_POINT_CHANGED, NEW_LINE_ADDED, POINT_SELECTED, POINT_CHANGED, RIGHT_CLICK, SCROLLED, DELETE_REGION_SELECTED };
+    enum CPEventMode { NONE, NEW_POINT_CHANGED, NEW_LINE_ADDED, POINT_SELECTED, POINT_CHANGED, RIGHT_CLICK, SCROLLED, DELETE_REGION_SELECTED, CANCELED };
 
 public:
     CPEvent( );
@@ -121,7 +122,7 @@ public:
     /** remember the control, where the information should be drawn */
     void SetControl(CPImageCtrl* control);
     /** draw the control points to the given device context */
-    void Draw(wxDC& dc, bool selected, bool newPoint=false);
+    void Draw(wxDC& dc, const wxRect& visibleRect, bool selected, bool newPoint=false);
     /** check if given point is over label of cp, using screen coordinates */
     const bool isOccupiedLabel(const wxPoint mousePos) const;
     /** check if the given point is over the drawn cp, using image coordinates */
@@ -157,6 +158,8 @@ private:
     void DrawLine(wxDC& dc);
     /** draw line control point over different images */
     void DrawLineSegment(wxDC& dc);
+    /** return true, if line cp should be drawn as separate line */
+    bool IsDrawingLine() const;
     /** representation of underlying control point */
     HuginBase::ControlPoint m_cp;
     /** is first or second image in cp used */
@@ -259,6 +262,7 @@ public:
     void setImage (const std::string & filename, ImageRotation rot);
     void setSameImage(bool sameImage);
     void setTransforms(HuginBase::PTools::Transform* firstTrans, HuginBase::PTools::Transform* firstInvTrans, HuginBase::PTools::Transform* secondInvTrans);
+    void setMagTransforms(HuginBase::PTools::Transform* magTrans, HuginBase::PTools::Transform* magInvTrans);
     HuginBase::PTools::Transform* getFirstTrans() const { return m_firstTrans; };
     HuginBase::PTools::Transform* getFirstInvTrans() const { return m_firstInvTrans; };
     HuginBase::PTools::Transform* getSecondInvTrans() const { return m_secondInvTrans; };
@@ -275,7 +279,7 @@ public:
     void setNewPoint(const hugin_utils::FDiff2D & p);
 
     /// select a point for usage
-    void selectPoint(unsigned int);
+    void selectPoint(unsigned int, bool scrollTo = true);
 
     /// remove selection.
     void deselect();
@@ -427,24 +431,29 @@ public:
     const bool GetMouseInWindow() const { return m_mouseInWindow; };
     const bool GetForceMagnifier() const { return m_forceMagnifier; };
     /** get pointer to image, for DisplayedControlPoint */
-    const HuginBase::ImageCache::ImageCacheRGB8Ptr GetImg() const { return m_img->image8; };
+    HuginBase::ImageCache::ImageCacheRGB8Ptr GetImg();
     /** draw the magnified view of a selected control point */
-    wxBitmap generateMagBitmap(hugin_utils::FDiff2D point, wxPoint canvasPos) const;
+    wxBitmap& GetMagBitmap(hugin_utils::FDiff2D point);
     /** return the real size of the image in the control */
     const wxSize GetRealImageSize() const { return m_realSize; };
     /** return the size of the drawn bitmap (possible rotate is applied) */
     const wxSize GetBitmapSize() const;
 
+    virtual void OnDraw(wxDC& dc);
+
+    // setting/getting option if line cp should be shown as separate line
+    void ShowLines(bool isShown);
+    bool IsShowingLines() const;
 protected:
     // display the image when loading finishes
     void OnImageLoaded(ImageCache::EntryPtr entry, std::string filename, bool load_small);
-    void OnDraw(wxDC& dc);
     void OnSize(wxSizeEvent & e);
     void OnKey(wxKeyEvent & e);
     void OnKeyDown(wxKeyEvent & e);
     void OnMouseLeave(wxMouseEvent & e);
     void OnMouseEnter(wxMouseEvent & e);
     void OnTimer(wxTimerEvent & e);
+    void OnScrollWin(wxScrollWinEvent & e);
 
     /// helper func to emit a region
     bool emit(CPEvent & ev);
@@ -465,6 +474,13 @@ private:
     wxSize imageSize;
     // size of real image
     wxSize m_realSize;
+    // for drawing overlay
+    wxOverlay m_overlay;
+    // cache mag image
+    wxBitmap m_magImg;
+    hugin_utils::FDiff2D m_magImgCenter;
+    // should line cp shown as line
+    bool m_showLines { true };
 
     std::vector<DisplayedControlPoint> m_points;
 
@@ -491,6 +507,9 @@ private:
     HuginBase::PTools::Transform* m_firstTrans;
     HuginBase::PTools::Transform* m_firstInvTrans;
     HuginBase::PTools::Transform* m_secondInvTrans;
+    // store pointer to transformation for drawing the magnifier
+    HuginBase::PTools::Transform* m_magTrans;
+    HuginBase::PTools::Transform* m_magInvTrans;
 
     // colors for the different points
     std::vector<wxColour> pointColors;
