@@ -113,6 +113,7 @@ bool CPListCtrl::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos,
     };
     EnableAlternateRowColours(true);
 
+#if !wxCHECK_VERSION(3,1,6)
     wxMemoryDC memDC;
     memDC.SetFont(GetFont());
     wxSize fontSize = memDC.GetTextExtent(wxT("\u25b3"));
@@ -141,11 +142,16 @@ bool CPListCtrl::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos,
         sortIcons->Add(bmp, GetBackgroundColour());
     };
     AssignImageList(sortIcons, wxIMAGE_LIST_SMALL);
+#endif
     wxConfigBase* config = wxConfig::Get();
     m_sortCol=config->Read(wxT("/CPListFrame/SortColumn"), 0l);
     m_sortAscend = config->Read(wxT("/CPListFrame/SortAscending"), 1l) == 1;
     config->Flush();
+#if wxCHECK_VERSION(3,1,6)
+    ShowSortIndicator(m_sortCol, m_sortAscend);
+#else
     SetColumnImage(m_sortCol, m_sortAscend ? 0 : 1);
+#endif
     return true;
 };
 
@@ -266,62 +272,56 @@ void CPListCtrl::UpdateInternalCPList()
 };
 
 // sort helper function
-#define CompareStruct(VAR) \
-struct Compare##VAR\
+// sort by global or local number only
+#define CompareStruct(VAR, TYPESUFFIX, OP) \
+struct Compare##TYPESUFFIX\
 {\
     bool operator()(const CPListItem& item1, const CPListItem& item2)\
     {\
-        return item1.VAR < item2.VAR;\
+        return item1.VAR OP item2.VAR;\
     };\
 };
-CompareStruct(globalIndex)
-CompareStruct(localNumber)
+CompareStruct(globalIndex, globalIndex, <)
+CompareStruct(globalIndex, globalIndexGreater, >)
+CompareStruct(localNumber, localNumber, <)
+CompareStruct(localNumber, localNumberGreater, >)
 #undef CompareStruct
 
-#define CompareStruct(VAR) \
-struct Compare##VAR##Greater\
+// sort by image number, take second image number as second criterion and local number as third
+#define CompareStruct(VAR1, VAR2, TYPESUFFIX, OP)\
+struct Compare##TYPESUFFIX\
 {\
+    explicit Compare##TYPESUFFIX(const HuginBase::CPVector& cps) : m_cps(cps) {};\
     bool operator()(const CPListItem& item1, const CPListItem& item2)\
     {\
-        return item1.VAR > item2.VAR;\
-    };\
-};
-CompareStruct(globalIndex)
-CompareStruct(localNumber)
-#undef CompareStruct
-
-#define CompareStruct(VAR)\
-struct Compare##VAR\
-{\
-    explicit Compare##VAR(const HuginBase::CPVector& cps) : m_cps(cps) {};\
-    bool operator()(const CPListItem& item1, const CPListItem& item2)\
-    {\
-         return m_cps[item1.globalIndex].VAR < m_cps[item2.globalIndex].VAR; \
+         return m_cps[item1.globalIndex].VAR1 * 1e4 + m_cps[item1.globalIndex].VAR2 + item1.localNumber * 1.0 / m_cps.size() OP\
+                m_cps[item2.globalIndex].VAR1 * 1e4 + m_cps[item2.globalIndex].VAR2 + item2.localNumber * 1.0 / m_cps.size();\
     }\
 private:\
     const HuginBase::CPVector& m_cps;\
 };
-CompareStruct(image1Nr)
-CompareStruct(image2Nr)
-CompareStruct(mode)
-CompareStruct(error)
+CompareStruct(image1Nr, image2Nr, image1Nr, <)
+CompareStruct(image1Nr, image2Nr, image1NrGreater, >)
+CompareStruct(image2Nr, image1Nr, image2Nr, <)
+CompareStruct(image2Nr, image1Nr, image2NrGreater, >)
 #undef CompareStruct
 
-#define CompareStruct(VAR)\
-struct Compare##VAR##Greater\
+// sort by mode or error
+#define CompareStruct(VAR, TYPESUFFIX, OP)\
+struct Compare##TYPESUFFIX\
 {\
-    explicit Compare##VAR##Greater(const HuginBase::CPVector& cps) : m_cps(cps) {};\
+    explicit Compare##TYPESUFFIX(const HuginBase::CPVector& cps) : m_cps(cps) {};\
     bool operator()(const CPListItem& item1, const CPListItem& item2)\
     {\
-         return m_cps[item1.globalIndex].VAR > m_cps[item2.globalIndex].VAR; \
+         return m_cps[item1.globalIndex].VAR OP m_cps[item2.globalIndex].VAR;\
     }\
 private:\
     const HuginBase::CPVector& m_cps;\
 };
-CompareStruct(image1Nr)
-CompareStruct(image2Nr)
-CompareStruct(mode)
-CompareStruct(error)
+CompareStruct(mode, mode, <)
+CompareStruct(mode, modeGreater, >)
+CompareStruct(error, error, <)
+CompareStruct(error, errorGreater, >)
 #undef CompareStruct
 
 void CPListCtrl::SortInternalList(bool isAscending)
@@ -414,6 +414,18 @@ void CPListCtrl::OnCPListSelectionChanged(wxListEvent & e)
 void CPListCtrl::OnCPListHeaderClick(wxListEvent& e)
 {
     const int newCol = e.GetColumn();
+#if wxCHECK_VERSION(3,1,6)
+    if (m_sortCol == newCol)
+    {
+        m_sortAscend = !m_sortAscend;
+    }
+    else
+    {
+        m_sortCol = newCol;
+        m_sortAscend = true;
+    };
+    ShowSortIndicator(m_sortCol, m_sortAscend);
+#else
     if (m_sortCol == newCol)
     {
         m_sortAscend = !m_sortAscend;
@@ -426,6 +438,7 @@ void CPListCtrl::OnCPListHeaderClick(wxListEvent& e)
         SetColumnImage(m_sortCol, 0);
         m_sortAscend = true;
     }
+#endif
     SortInternalList(false);
     Refresh();
 };
