@@ -138,16 +138,14 @@ public:
     }
     ~GLOverview();
 
-    void SetPanosphereMode();
-    void SetPlaneMode();
-    
     void setUp();
 
     virtual void SetLayoutMode(bool state);
     virtual void SetLayoutScale(double scale);
 
     enum OverviewMode {
-        PANOSPHERE,
+        PANOSPHERE_OUTSIDE,
+        PANOSPHERE_INSIDE,
         PLANE
     };
 
