@@ -141,6 +141,10 @@ protected:
     void OnActivateImage(wxCommandEvent& e);
     /** event handler for deactivate image */
     void OnDeactivateImage(wxCommandEvent& e);
+#if wxCHECK_VERSION(3,1,3)
+    /** event handler for updating dpi */
+    void OnDpiChanged(wxDPIChangedEvent& e);
+#endif
 
 private:
     /** creates all columns and stores information in m_columnMap, m_columnVector, m_editableColumns and m_variableVector */
@@ -158,6 +162,9 @@ private:
     void GenerateSubMenu(wxMenu* menu, PanoOperation::PanoOperationVector* operations, int& id);
     /** update the font colour for all items */
     void UpdateItemFont();
+    /** create image list with necessary images of checkboxes */
+    void CreateCheckboxImages();
+
 
     // the model
     HuginBase::Panorama * m_pano;
