@@ -53,11 +53,13 @@ PanoOutputDialog::PanoOutputDialog(wxWindow *parent, HuginBase::Panorama& pano,
     wxXmlResource::Get()->LoadDialog(this, parent, wxT("pano_output_dialog"));
 
 #ifdef __WXMSW__
-    wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/hugin.ico"),wxBITMAP_TYPE_ICO);
+    wxIconBundle myIcons(huginApp::Get()->GetXRCPath() + wxT("data/hugin.ico"),wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
 #else
     wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/hugin.png"),wxBITMAP_TYPE_PNG);
-#endif
     SetIcon(myIcon);
+#endif
+
     //set parameters
     wxConfigBase * cfg = wxConfigBase::Get();
     //position
