@@ -1082,7 +1082,7 @@ void PanoPanel::DoCalcOptimalROI(wxCommandEvent & e)
     };
 };
 
-void PanoPanel::DoStitch()
+void PanoPanel::DoStitch(const wxString& userDefinedSetting)
 {
     if (pano->getNrOfImages() == 0) {
         return;
@@ -1112,13 +1112,7 @@ void PanoPanel::DoStitch()
     }
     DEBUG_DEBUG("tmp PTO file: " << (const char *)currentPTOfn.mb_str(wxConvLocal));
     // copy is not enough, need to adjust image path names...
-    std::ofstream script(currentPTOfn.mb_str(HUGIN_CONV_FILENAME));
-    HuginBase::UIntSet all;
-    if (pano->getNrOfImages() > 0) {
-        fill_set(all, 0, pano->getNrOfImages()-1);
-    }
-    pano->printPanoramaScript(script, pano->getOptimizeVector(), pano->getOptions(), all, false, "");
-    script.close();
+    pano->WritePTOFile(std::string(currentPTOfn.mb_str(HUGIN_CONV_FILENAME)));
 
 //    wxCommandEvent dummy;
 //    MainFrame::Get()->OnSaveProject(dummy);
@@ -1145,7 +1139,7 @@ void PanoPanel::DoStitch()
 
     // Derive a default output prefix from the project filename if set, otherwise default project filename
     wxFileName outputPrefix(getDefaultOutputName(MainFrame::Get()->getProjectName(), *pano));
-    outputPrefix.Normalize();
+    outputPrefix.Normalize(wxPATH_NORM_ABSOLUTE | wxPATH_NORM_DOTS | wxPATH_NORM_TILDE | wxPATH_NORM_SHORTCUT);
 
     // Show a file save dialog so user can confirm/change the prefix.
     // (We don't have to worry about overwriting existing files, since hugin_switch_project checks this.)
@@ -1191,6 +1185,10 @@ void PanoPanel::DoStitch()
     wxString switches(wxT(" --delete -o "));
     if(wxConfigBase::Get()->Read(wxT("/Processor/overwrite"), HUGIN_PROCESSOR_OVERWRITE) == 1)
         switches=wxT(" --overwrite")+switches;
+    if (!userDefinedSetting.IsEmpty())
+    {
+        switches = " --user-defined-output=" + hugin_utils::wxQuoteFilename(userDefinedSetting) + " " + switches;
+    };
     wxString command = hugin_stitch_project + switches + hugin_utils::wxQuoteFilename(dlg.GetPath()) + wxT(" ") + hugin_utils::wxQuoteFilename(currentPTOfn);
     
     wxConfigBase::Get()->Flush();
@@ -1209,7 +1207,7 @@ void PanoPanel::DoStitch()
     HuginBase::LensDB::SaveLensDataFromPano(*pano);
 }
 
-void PanoPanel::DoSendToBatch()
+void PanoPanel::DoSendToBatch(const wxString& userDefinedSetting)
 {
     if (pano->getNrOfImages() == 0)
     {
@@ -1231,15 +1229,19 @@ void PanoPanel::DoSendToBatch()
     if (wxConfigBase::Get()->Read(wxT("/Processor/start"), HUGIN_PROCESSOR_START) != 0)
     {
         switches += wxT("-b ");
-    }
+    };
     if (wxConfigBase::Get()->Read(wxT("/Processor/overwrite"), HUGIN_PROCESSOR_OVERWRITE) != 0)
     {
         switches += wxT("-o ");
-    }
+    };
     if (wxConfigBase::Get()->Read(wxT("/Processor/verbose"), HUGIN_PROCESSOR_VERBOSE) != 0)
     {
         switches += wxT("-v ");
-    }
+    };
+    if (!userDefinedSetting.IsEmpty())
+    {
+        switches += "--user-defined=" + hugin_utils::wxQuoteFilename(userDefinedSetting) + " ";
+    };
     if(pano->isDirty())
     {
         bool showDlg=wxConfigBase::Get()->Read(wxT("ShowSaveMessage"), 1l)==1;
@@ -1278,7 +1280,7 @@ void PanoPanel::DoSendToBatch()
     if(wxFileName::FileExists(projectFile))
     {
         wxFileName outputPrefix(getDefaultOutputName(projectFile, *pano));
-        outputPrefix.Normalize();
+        outputPrefix.Normalize(wxPATH_NORM_ABSOLUTE | wxPATH_NORM_DOTS | wxPATH_NORM_TILDE | wxPATH_NORM_SHORTCUT);
 
         // Show a file save dialog so user can confirm/change the prefix.
         // (We don't have to worry about overwriting existing files, since PTBatcherGUI checks this, or the overwrite flag was set.)
@@ -1370,7 +1372,7 @@ void PanoPanel::DoUserDefinedStitch(const wxString& settings)
         wxString path = config->Read(wxT("/userDefinedOutputPath"), MainFrame::Get()->GetDataPath());
         wxFileDialog userOutputDlg(this, _("Select user defined output"),
             path, wxT(""), _("User defined output|*.executor"),
-            wxFD_OPEN | wxFD_MULTIPLE | wxFD_FILE_MUST_EXIST, wxDefaultPosition);
+            wxFD_OPEN | wxFD_FILE_MUST_EXIST, wxDefaultPosition);
         if (userOutputDlg.ShowModal() != wxID_OK)
         {
             return;
@@ -1389,123 +1391,10 @@ void PanoPanel::DoUserDefinedStitch(const wxString& settings)
             return;
         };
     };
-
-    // create a copy, if we need to update the crop setting
-    // save project
-    // copy pto file to temporary file
-    wxString tempDir = wxConfigBase::Get()->Read(wxT("tempDir"), wxT(""));
-    if (!tempDir.IsEmpty())
-    {
-        if (tempDir.Last() != wxFileName::GetPathSeparator())
-        {
-            tempDir.Append(wxFileName::GetPathSeparator());
-        }
-    };
-    wxString currentPTOfn = wxFileName::CreateTempFileName(tempDir + wxT("huginpto_"));
-    if (currentPTOfn.empty())
-    {
-        wxMessageBox(_("Could not create temporary project file"), _("Error"),
-            wxCANCEL | wxICON_ERROR, this);
-        return;
-    }
-    DEBUG_DEBUG("tmp PTO file: " << (const char *)currentPTOfn.mb_str(wxConvLocal));
-    // copy is not enough, need to adjust image path names...
-    std::ofstream script(currentPTOfn.mb_str(HUGIN_CONV_FILENAME));
-    HuginBase::UIntSet all;
-    fill_set(all, 0, pano->getNrOfImages() - 1);
-    pano->printPanoramaScript(script, pano->getOptimizeVector(), pano->getOptions(), all, false, "");
-    script.close();
-
-    //    wxCommandEvent dummy;
-    //    MainFrame::Get()->OnSaveProject(dummy);
-
-#if defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
-    // HuginStitchProject inside main bundle
-    wxString hugin_stitch_project = MacGetPathToBundledAppMainExecutableFile(CFSTR("HuginStitchProject.app"));
-    if (hugin_stitch_project == wxT(""))
-    {
-        DEBUG_ERROR("hugin_stitch_project could not be found in the bundle.");
-        return;
-    }
-    hugin_stitch_project = hugin_utils::wxQuoteFilename(hugin_stitch_project);
-#elif defined __WXMAC__
-    // HuginStitchProject installed in INSTALL_OSX_BUNDLE_DIR
-    wxFileName hugin_stitch_project_app(wxT(INSTALL_OSX_BUNDLE_DIR), wxEmptyString);
-    hugin_stitch_project_app.AppendDir(wxT("HuginStitchProject.app"));
-    CFStringRef stitchProjectAppPath = MacCreateCFStringWithWxString(hugin_stitch_project_app.GetFullPath());
-    wxString hugin_stitch_project = MacGetPathToMainExecutableFileOfBundle(stitchProjectAppPath);
-    CFRelease(stitchProjectAppPath);
-#else
-    wxString hugin_stitch_project = wxT("hugin_stitch_project");
-#endif
-
-    // Derive a default output prefix from the project filename if set, otherwise default project filename
-    wxFileName outputPrefix(getDefaultOutputName(MainFrame::Get()->getProjectName(), *pano));
-    outputPrefix.Normalize();
-
-    // Show a file save dialog so user can confirm/change the prefix.
-    // (We don't have to worry about overwriting existing files, since hugin_switch_project checks this.)
-    // TODO: The following code is similar to stitchApp::OnInit in hugin_switch_project.cpp. Should be refactored.
-    // TODO: We should save the output prefix somewhere, so we can recall it as the default if the user stitches this project again.
-    wxFileDialog dlg(this, _("Specify output prefix"),
-        outputPrefix.GetPath(), outputPrefix.GetName(), wxT(""),
-        wxFD_SAVE, wxDefaultPosition);
-    if (dlg.ShowModal() != wxID_OK)
-    {
-        return;
-    };
-    while (containsInvalidCharacters(dlg.GetPath()))
-    {
-        wxArrayString list;
-        list.Add(dlg.GetPath());
-        ShowFilenameWarning(this, list);
-        if (dlg.ShowModal() != wxID_OK)
-            return;
-    };
-    wxFileName prefix(dlg.GetPath());
-    while (!prefix.IsDirWritable())
-    {
-        wxMessageBox(wxString::Format(_("You have no permissions to write in folder \"%s\".\nPlease select another folder for the final output."), prefix.GetPath().c_str()),
-#ifdef __WXMSW__
-            wxT("Hugin"),
-#else
-            wxT(""),
-#endif
-            wxOK | wxICON_INFORMATION);
-        if (dlg.ShowModal() != wxID_OK)
-        {
-            return;
-        };
-        prefix = dlg.GetPath();
-    };
-    // check free space
-    if (!CheckFreeSpace(prefix.GetPath()))
-    {
-        return;
-    };
-
-    wxString switches(wxT(" --user-defined-output=") + hugin_utils::wxQuoteFilename(userOutputSequence.GetFullPath()) + wxT(" --delete -o "));
-    if (wxConfigBase::Get()->Read(wxT("/Processor/overwrite"), HUGIN_PROCESSOR_OVERWRITE) == 1)
-        switches = wxT(" --overwrite") + switches;
-    wxString command = hugin_stitch_project + switches + hugin_utils::wxQuoteFilename(dlg.GetPath()) + wxT(" ") + hugin_utils::wxQuoteFilename(currentPTOfn);
-
-    wxConfigBase::Get()->Flush();
-#ifdef __WXGTK__
-    // work around a wxExecute bug/problem
-    // (endless polling of fd 0 and 1 in hugin_stitch_project)
-    wxProcess *my_process = new wxProcess(this);
-    my_process->Redirect();
-
-    // Delete itself once processes terminated.
-    my_process->Detach();
-    wxExecute(command, wxEXEC_ASYNC, my_process);
-#else
-    wxExecute(command);
-#endif
+    DoStitchOrSendBatch(userOutputSequence.GetFullPath());
 }
 
-
-void PanoPanel::OnDoStitch ( wxCommandEvent & e )
+void PanoPanel::DoStitchOrSendBatch(const wxString& userDefinedSetting)
 {
     long t;
     if(wxGetKeyState(WXK_COMMAND))
@@ -1514,17 +1403,17 @@ void PanoPanel::OnDoStitch ( wxCommandEvent & e )
     }
     else
     {
-        wxConfigBase::Get()->Read(wxT("/Processor/gui"),&t,HUGIN_PROCESSOR_GUI);
+        wxConfigBase::Get()->Read(wxT("/Processor/gui"), &t, HUGIN_PROCESSOR_GUI);
     };
     switch (t)
     {
         // PTBatcher
         case 0:
-            DoSendToBatch();
+            DoSendToBatch(userDefinedSetting);
             break;
         // hugin_stitch_project
         case 1:
-            DoStitch();
+            DoStitch(userDefinedSetting);
             break;
         // there is an error in the preferences
         default :
@@ -1533,6 +1422,11 @@ void PanoPanel::OnDoStitch ( wxCommandEvent & e )
       }
 }
 
+void PanoPanel::OnDoStitch(wxCommandEvent& e)
+{
+    DoStitchOrSendBatch();
+}
+
 void PanoPanel::FileFormatChanged(wxCommandEvent & e)
 {
 
