@@ -72,11 +72,14 @@ public:
     virtual void panoramaImagesChanged(HuginBase::Panorama &pano, const HuginBase::UIntSet & imgNr) {};
 
     /** stitching using hugin_stitch_project */
-    void DoStitch();
+    void DoStitch(const wxString& userDefinedSetting = wxEmptyString);
     /** stitching with PTBatcherGUI */
-    void DoSendToBatch();
+    void DoSendToBatch(const wxString& userDefinedSetting = wxEmptyString);
     /** stitching with user defined file */
     void DoUserDefinedStitch(const wxString& settings = wxString());
+    /** general stitching command, selects PTBatcherGUI or hugin_stitch_project 
+        depending on the settings in preferences */
+    void DoStitchOrSendBatch(const wxString& userDefinedSetting = wxEmptyString);
 
     void SetGuiLevel(GuiLevel newGuiLevel);
 
