@@ -25,10 +25,12 @@
  *
  */
 
-#include "hugin/PreviewEditCPTool.h"
 #include "panoinc_WX.h"
 #include "panoinc.h"
+#include "hugin/PreviewEditCPTool.h"
 #include <map>
+#include "base_wx/CommandHistory.h"
+#include "base_wx/wxPanoCommand.h"
 
 #include <wx/platform.h>
 #ifdef __WXMAC__
@@ -49,7 +51,7 @@ void PreviewEditCPTool::Activate()
     helper->NotifyMe(PreviewToolHelper::MOUSE_MOVE, this);
     helper->NotifyMe(PreviewToolHelper::REALLY_DRAW_OVER_IMAGES, this);
     m_mouseDown = false;
-    helper->SetStatusMessage(_("Drag a rectangle and select the desired action for the control points in the selected rectangle."));
+    helper->SetStatusMessage(_("Drag a rectangle and select the desired action for the control points in the selected rectangle. Alt + drag to create a line control point."));
 };
 
 // The panorama has been drawn, now draw the selection rectangle.
@@ -60,7 +62,7 @@ void PreviewEditCPTool::ReallyAfterDrawImagesEvent()
         glDisable(GL_TEXTURE_2D);
         const hugin_utils::FDiff2D dist(m_currentPosScreen - m_startPosScreen);
         // select color depending on size
-        if (fabs(dist.x) > 10 && fabs(dist.y) > 10)
+        if (m_line || (fabs(dist.x) > 10 && fabs(dist.y) > 10))
         {
             glColor3f(1.0f, 1.0f, 0.0f);
         }
@@ -69,16 +71,26 @@ void PreviewEditCPTool::ReallyAfterDrawImagesEvent()
             // selection is too small, use a gray color
             glColor3f(0.7f, 0.7f, 0.7f);
         }
-        glBegin(GL_LINES);
-        glVertex2f(m_startPos.x, m_startPos.y);
-        glVertex2f(m_currentPos.x, m_startPos.y);
-        glVertex2f(m_currentPos.x, m_startPos.y);
-        glVertex2f(m_currentPos.x, m_currentPos.y);
-        glVertex2f(m_currentPos.x, m_currentPos.y);
-        glVertex2f(m_startPos.x, m_currentPos.y);
-        glVertex2f(m_startPos.x, m_currentPos.y);
-        glVertex2f(m_startPos.x, m_startPos.y);
-        glEnd();
+        if (m_line)
+        {
+            glBegin(GL_LINES);
+            glVertex2f(m_startPos.x, m_startPos.y);
+            glVertex2f(m_currentPos.x, m_currentPos.y);
+            glEnd();
+        }
+        else
+        {
+            glBegin(GL_LINES);
+            glVertex2f(m_startPos.x, m_startPos.y);
+            glVertex2f(m_currentPos.x, m_startPos.y);
+            glVertex2f(m_currentPos.x, m_startPos.y);
+            glVertex2f(m_currentPos.x, m_currentPos.y);
+            glVertex2f(m_currentPos.x, m_currentPos.y);
+            glVertex2f(m_startPos.x, m_currentPos.y);
+            glVertex2f(m_startPos.x, m_currentPos.y);
+            glVertex2f(m_startPos.x, m_startPos.y);
+            glEnd();
+        };
         glEnable(GL_TEXTURE_2D);
     };
 };
@@ -114,6 +126,7 @@ void PreviewEditCPTool::MouseButtonEvent(wxMouseEvent &e)
             m_startPos = helper->GetMousePanoPosition();
             m_startPosScreen = helper->GetMouseScreenPosition();
             m_CPinROI.clear();
+            m_line = e.AltDown();
         }
         else
         {
@@ -123,40 +136,48 @@ void PreviewEditCPTool::MouseButtonEvent(wxMouseEvent &e)
                 m_mouseDown = false;
                 m_currentPos = helper->GetMousePanoPosition();
                 m_currentPosScreen = helper->GetMouseScreenPosition();
-                const hugin_utils::FDiff2D dist (m_currentPosScreen - m_startPosScreen);
-                if (fabs(dist.x)>10 && fabs(dist.y)>10)
+                if (m_line)
                 {
-                    // build menu
-                    wxMenu menu;
-                    const vigra::Rect2D roi = GetSelectedROI();
-                    // selected roi should have at least 10 pixel width and height in pano space
-                    if (!roi.isEmpty() && roi.width() > 10 && roi.height() > 10)
+                    // now add the line cp
+                    AddLineCP(m_startPos, m_currentPos);
+                }
+                else
+                {
+                    const hugin_utils::FDiff2D dist(m_currentPosScreen - m_startPosScreen);
+                    if (fabs(dist.x) > 10 && fabs(dist.y) > 10)
                     {
-                        menu.Append(ID_CREATE_CP, _("Create control points here"));
-                    }
-                    FindCPInRect(m_startPos, m_currentPos);
-                    if (!m_CPinROI.empty())
-                    {
-                        menu.Append(ID_REMOVE_CP, wxString::Format(_("Remove %lu control points"), static_cast<unsigned long int>(m_CPinROI.size())));
-                    }
-                    if (!menu.GetMenuItems().IsEmpty())
-                    {
-                        m_menuPopup = true;
-                        helper->GetPreviewFrame()->PopupMenu(&menu);
+                        // build menu
+                        wxMenu menu;
+                        const vigra::Rect2D roi = GetSelectedROI();
+                        // selected roi should have at least 10 pixel width and height in pano space
+                        if (!roi.isEmpty() && roi.width() > 10 && roi.height() > 10)
+                        {
+                            menu.Append(ID_CREATE_CP, _("Create control points here"));
+                        };
+                        FindCPInRect(m_startPos, m_currentPos);
+                        if (!m_CPinROI.empty())
+                        {
+                            menu.Append(ID_REMOVE_CP, wxString::Format(_("Remove %lu control points"), static_cast<unsigned long int>(m_CPinROI.size())));
+                        };
+                        if (!menu.GetMenuItems().IsEmpty())
+                        {
+                            m_menuPopup = true;
+                            helper->GetPreviewFrame()->PopupMenu(&menu);
+                        }
+                        else
+                        {
+                            wxBell();
+                            helper->GetVisualizationStatePtr()->ForceRequireRedraw();
+                            helper->GetVisualizationStatePtr()->Redraw();
+                        };
                     }
                     else
                     {
                         wxBell();
+                        // we need to redraw so that the selection rectangle vanishes
                         helper->GetVisualizationStatePtr()->ForceRequireRedraw();
                         helper->GetVisualizationStatePtr()->Redraw();
-                    }
-                }
-                else
-                {
-                    wxBell();
-                    // we need to redraw so that the selection rectangle vanishes
-                    helper->GetVisualizationStatePtr()->ForceRequireRedraw();
-                    helper->GetVisualizationStatePtr()->Redraw();
+                    };
                 };
             };
         };
@@ -228,3 +249,45 @@ void PreviewEditCPTool::SetMenuProcessed()
 {
     m_menuPopup = false;
 };
+
+void PreviewEditCPTool::AddLineCP(const hugin_utils::FDiff2D& pos1, const hugin_utils::FDiff2D& pos2)
+{
+    HuginBase::UIntSet imgs1 = helper->GetImagesUnderPos(pos1);
+    HuginBase::UIntSet imgs2 = helper->GetImagesUnderPos(pos2);
+    HuginBase::UIntSet imgIntersection;
+    std::set_intersection(imgs1.begin(), imgs1.end(), imgs2.begin(), imgs2.end(), std::inserter(imgIntersection, imgIntersection.begin()));
+    if (!imgIntersection.empty())
+    {
+        // start and end point are on the same image
+        HuginBase::Panorama* pano = helper->GetPanoramaPtr();
+        HuginBase::ControlPoint cp;
+        cp.image1Nr = *imgIntersection.begin();
+
+        HuginBase::PTools::Transform transform;
+        transform.createTransform(pano->getImage(cp.image1Nr), pano->getOptions());
+        double image_x, image_y;
+        transform.transformImgCoord(image_x, image_y, pos1.x, pos1.y);
+        cp.x1 = image_x;
+        cp.y1 = image_y;
+        transform.transformImgCoord(image_x, image_y, pos2.x, pos2.y);
+        cp.image2Nr = cp.image1Nr;
+        cp.x2 = image_x;
+        cp.y2 = image_y;
+        if (abs(pos1.x - pos2.x) < abs(pos1.y - pos2.y))
+        {
+            cp.mode = HuginBase::ControlPoint::X;
+        }
+        else
+        {
+            cp.mode = HuginBase::ControlPoint::Y;
+        };
+        PanoCommand::GlobalCmdHist::getInstance().addCommand(new PanoCommand::AddCtrlPointCmd(*pano, cp));
+    }
+    else
+    {
+        wxBell();
+        // we need to redraw so that the selection vanishes
+        helper->GetVisualizationStatePtr()->ForceRequireRedraw();
+        helper->GetVisualizationStatePtr()->Redraw();
+    };
+}
\ No newline at end of file
