@@ -48,7 +48,11 @@
 
 // The OpenGL Extension wrangler libray will find extensions and the latest
 // supported OpenGL version on all platforms.
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#include <epoxy/gl.h>
+#else
 #include <GL/glew.h>
+#endif
 #include <wx/platform.h>
 #include <wx/display.h>
 
@@ -628,7 +632,11 @@ void TextureManager::TextureInfo::SetParameters()
     if (!checked_anisotropic)
     {
         // check if it is supported
+#if defined HAVE_EPOXY && HAVE_EPOXY
+        if (epoxy_has_gl_extension("GL_EXT_texture_filter_anisotropic"))
+#else
         if (GLEW_EXT_texture_filter_anisotropic)
+#endif
         {
             has_anisotropic = true;
             glGetFloatv(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, &anisotropy);
