@@ -106,6 +106,45 @@ void ToolHelper::InvalidateImagesUnderMouse()
     }
 }
 
+void ToolHelper::UpdateImagesUnderMouse()
+{
+    // We want to find out which images cover the point underneath the mouse
+    // pointer.
+    images_under_mouse.clear();
+    if (IsMouseOverPano())
+    {
+        images_under_mouse = GetImagesUnderPos(hugin_utils::FDiff2D(mouse_pano_x, mouse_pano_y));
+    };
+    images_under_mouse_current = true;
+}
+
+HuginBase::UIntSet ToolHelper::GetImagesUnderPos(const hugin_utils::FDiff2D& pos)
+{
+    HuginBase::UIntSet imgUnderPos;
+    const unsigned int num_images = pano->getNrOfImages();
+    HuginBase::UIntSet displayedImages = pano->getActiveImages();
+    for (unsigned int image_index = 0; image_index < num_images; image_index++)
+    {
+        // don't try any images that are turned off
+        if (set_contains(displayedImages, image_index))
+        {
+            // work out if the image covers the point under the mouse.
+            HuginBase::PTools::Transform transform;
+            transform.createTransform(*visualization_state->GetSrcImage(image_index),
+                *visualization_state->GetOptions());
+            double image_x, image_y;
+            transform.transformImgCoord(image_x, image_y, pos.x, pos.y);
+            if (visualization_state->getViewState()->GetSrcImage(image_index)->isInside(vigra::Point2D(
+                int(image_x), int(image_y))))
+            {
+                // this image is under the position, add it to the set.
+                imgUnderPos.insert(image_index);
+            };
+        };
+    };
+    return imgUnderPos;
+}
+
 void ToolHelper::MouseButtonEvent(wxMouseEvent &e)
 {
     for (auto& tool : mouse_button_notified_tools)
@@ -468,66 +507,6 @@ void PreviewToolHelper::MouseMoved(int x, int y, wxMouseEvent &e)
     InvalidateImagesUnderMouse();
 }
 
-void PreviewToolHelper::UpdateImagesUnderMouse()
-{
-    // We want to find out which images cover the point underneath the mouse
-    // pointer.
-    images_under_mouse.clear();
-    if (IsMouseOverPano()) {
-        unsigned int num_images = pano->getNrOfImages();
-        std::set<unsigned int> displayedImages = pano->getActiveImages();
-        for (unsigned int image_index = 0; image_index < num_images; image_index++)
-        {
-            // don't try any images that are turned off
-            if (displayedImages.count(image_index))
-            {
-                // work out if the image covers the point under the mouse.
-                HuginBase::PTools::Transform transform;
-                transform.createTransform(*visualization_state->GetSrcImage(image_index),
-                                          *visualization_state->GetOptions());
-                double image_x, image_y;
-                transform.transformImgCoord(image_x, image_y, mouse_pano_x, mouse_pano_y);
-                if (visualization_state->getViewState()->GetSrcImage(image_index)->isInside(vigra::Point2D(
-                                                      int(image_x), int (image_y))))
-                {
-                    // this image is under the mouse, add it to the set.
-                    images_under_mouse.insert(image_index);
-                }
-            }
-        }
-    }
-    images_under_mouse_current = true;
-}
-
-void PanosphereOverviewToolHelper::UpdateImagesUnderMouse()
-{
-    images_under_mouse.clear();
-    if (IsMouseOverPano()) {
-        unsigned int num_images = pano->getNrOfImages();
-        std::set<unsigned int> displayedImages = pano->getActiveImages();
-        for (unsigned int image_index = 0; image_index < num_images; image_index++)
-        {
-            // don't try any images that are turned off
-            if (displayedImages.count(image_index))
-            {
-                // work out if the image covers the point under the mouse.
-                HuginBase::PTools::Transform transform;
-                transform.createTransform(*visualization_state->GetSrcImage(image_index),
-                                          *visualization_state->GetOptions());
-                double image_x, image_y;
-                transform.transformImgCoord(image_x, image_y, mouse_pano_x, mouse_pano_y);
-                if (visualization_state->getViewState()->GetSrcImage(image_index)->isInside(vigra::Point2D(
-                                                      int(image_x), int (image_y))))
-                {
-                    // this image is under the mouse, add it to the set.
-                    images_under_mouse.insert(image_index);
-                }
-            }
-        }
-    }
-    images_under_mouse_current = true;
-}
-
 void PanosphereOverviewToolHelper::MouseMoved(int x, int y, wxMouseEvent & e)
 {
     PanosphereOverviewVisualizationState * panostate = static_cast<PanosphereOverviewVisualizationState*>(visualization_state);
@@ -542,90 +521,109 @@ void PanosphereOverviewToolHelper::MouseMoved(int x, int y, wxMouseEvent & e)
     canv_w = tcanv_w;
     canv_h = tcanv_h;
     
-    double fov = panostate->getFOV();
+    const double fov = panostate->getFOV();
+    double fovScale = 1.0;
 
     double fovy, fovx;
-    if (canv_w > canv_h) {
+    if (canv_w > canv_h)
+    {
         fovy = DEG_TO_RAD(fov);
-        fovx = 2 * atan( tan(fovy / 2.0) * canv_w / canv_h);
-    } else {
+        fovx = 2 * atan(tan(fovy / 2.0) * canv_w / canv_h);
+        fovScale = tan(fovy / 2.0) / (0.5 * canv_h);
+    }
+    else
+    {
         fovx = DEG_TO_RAD(fov);
-        fovy = 2 * atan( tan(fovx / 2.0) * canv_h / canv_w);
-    }
-
-    double ax = tan(fovx / 2.0) * d * (x / (canv_w / 2.0) - 1);
-    double ay = tan(fovy / 2.0) * d * (y / (canv_h / 2.0) - 1);
-
-    double a_limit = r * d / sqrt(d*d - r*r);
-
-    if (ax*ax + ay*ay < a_limit*a_limit) {
+        fovy = 2 * atan(tan(fovx / 2.0) * canv_h / canv_w);
+        fovScale = tan(fovx / 2.0) / (0.5 * canv_w);
+    };
 
+    if (panostate->isInsideView())
+    {
+        // we are looking from inside, mouse is always about the panosphere
         mouse_over_pano = true;
-
-        double ta,tb,tc;
-        ta = (ax*ax + ay*ay) / (d*d) + 1;
-        tb = - 2 * (ax*ax + ay*ay) / d;
-        tc = ax*ax + ay*ay - r*r;
-
-        double pz = ( -tb + sqrt(tb*tb - 4*ta*tc) ) / ( 2 * ta );
-        double px = ax * (d - pz) / d;
-        double py = ay * (d - pz) / d;
-
-        double pl = sqrt(px*px + py*py + pz*pz);
-
-        double pang_yaw = -atan(px / pz);
-        double pang_pitch = asin(py / pl);
-
-        double ang_yaw = panostate->getAngX();
-        double ang_pitch = panostate->getAngY();
-
-        double x,y,z;
-        x = sin(ang_yaw)*cos(ang_pitch);
-        z = cos(ang_yaw)*cos(ang_pitch);
-        y = sin(ang_pitch);
-
-        Vector3 vec(x,y,z);
-
-        Vector3 top(0,1,0);
-
-        Vector3 ptop = vec.Cross(top).Cross(vec).GetNormalized();
-
-        Vector3 tres;
-        tres.x = ptop.x*(ptop.x * vec.x + ptop.y*vec.y + ptop.z*vec.z) + cos(pang_yaw) * (ptop.x * (-ptop.y * vec.y - ptop.z * vec.z) + vec.x*(ptop.y*ptop.y + ptop.z*ptop.z)) + sin(pang_yaw) * (-ptop.z*vec.y + ptop.y*vec.z);
-        tres.y = ptop.y*(ptop.x * vec.x + ptop.y*vec.y + ptop.z*vec.z) + cos(pang_yaw) * (ptop.y * (-ptop.x * vec.x - ptop.z * vec.z) + vec.y*(ptop.x*ptop.x + ptop.z*ptop.z)) + sin(pang_yaw) * (-ptop.z*vec.x + ptop.x*vec.z);
-        tres.z = ptop.z*(ptop.x * vec.x + ptop.y*vec.y + ptop.z*vec.z) + cos(pang_yaw) * (ptop.z * (-ptop.x * vec.x - ptop.y * vec.y) + vec.z*(ptop.x*ptop.x + ptop.y*ptop.y)) + sin(pang_yaw) * (-ptop.y*vec.x + ptop.x*vec.y);
-
-        Vector3 pside = ptop.Cross(tres).GetNormalized();
-        Vector3 res;
-
-        res.x = pside.x*(pside.x * tres.x + pside.y*tres.y + pside.z*tres.z) + cos(pang_pitch) * (pside.x * (-pside.y * tres.y - pside.z * tres.z) + tres.x*(pside.y*pside.y + pside.z*pside.z)) + sin(pang_pitch) * (-pside.z*tres.y + pside.y*tres.z);
-        res.y = pside.y*(pside.x * tres.x + pside.y*tres.y + pside.z*tres.z) + cos(pang_pitch) * (pside.y * (-pside.x * tres.x - pside.z * tres.z) + tres.y*(pside.x*pside.x + pside.z*pside.z)) + sin(-pang_pitch) * (-pside.z*tres.x + pside.x*tres.z);
-        res.z = pside.z*(pside.x * tres.x + pside.y*tres.y + pside.z*tres.z) + cos(pang_pitch) * (pside.z * (-pside.x * tres.x - pside.y * tres.y) + tres.z*(pside.x*pside.x + pside.y*pside.y)) + sin(pang_pitch) * (-pside.y*tres.x + pside.x*tres.y);
-
-        double yaw, pitch;
-        pitch = asin(res.y);
-        yaw = atan2(res.x , res.z);
-
-        yaw += M_PI / 2.0;
-        if (yaw < 0) yaw += 2 * M_PI;
-        if (yaw > 2 * M_PI) yaw -= 2 * M_PI;
-
-        pitch += M_PI / 2.0;
-        pitch = M_PI - pitch;
-
+        const double xSrc = (x - canv_w / 2.0) * fovScale;
+        const double ySrc = (canv_h / 2.0 - y) * fovScale;
+        const double yaw = atan(xSrc) + panostate->getAngX() + M_PI / 2.0;
+        const double pitch = M_PI/2.0 - atan2(ySrc, std::sqrt(1.0 + xSrc * xSrc)) - panostate->getAngY();
+        //if (yaw < 0) yaw += 2 * M_PI;
+        //if (yaw > 2 * M_PI) yaw -= 2 * M_PI;
         mouse_pano_x = yaw / (2 * M_PI) * panostate->GetOptions()->getWidth();
-        mouse_pano_y = pitch / (M_PI) * panostate->GetOptions()->getHeight();
-
-////        cerr << "mouse " << RAD_TO_DEG(yaw) << " " << RAD_TO_DEG(pitch) << " " << " ; " << RAD_TO_DEG(pang_yaw) << " " << RAD_TO_DEG(pang_pitch) << " ; " << RAD_TO_DEG(ang_yaw) << " " << RAD_TO_DEG(ang_pitch) << " ; " << px << " " << py << " " << pz << " ; " << ax << " " << ay);
-
-//        cerr << "mouse " << mouse_pano_x << " " << mouse_pano_y << " ; " << canv_w << " " << canv_h);
-
-//        double t_mouse_pano_x = yaw M
-
-    } else {
-
-        mouse_over_pano = false;
+        mouse_pano_y = pitch / (M_PI)*panostate->GetOptions()->getHeight();
     }
+    else
+    {
+        // we are looking from outside, more calculation to find position needed
+        const double ax = tan(fovx / 2.0) * d * (x / (canv_w / 2.0) - 1);
+        const double ay = tan(fovy / 2.0) * d * (y / (canv_h / 2.0) - 1);
+
+        const double a_limit = r * d / sqrt(d * d - r * r);
+
+        if (ax * ax + ay * ay < a_limit * a_limit)
+        {
+            mouse_over_pano = true;
+
+            const double ta = (ax * ax + ay * ay) / (d * d) + 1;
+            const double tb = -2 * (ax * ax + ay * ay) / d;
+            const double tc = ax * ax + ay * ay - r * r;
+
+            const double pz = (-tb + sqrt(tb * tb - 4 * ta * tc)) / (2 * ta);
+            const double px = ax * (d - pz) / d;
+            const double py = ay * (d - pz) / d;
+
+            const double pl = sqrt(px * px + py * py + pz * pz);
+
+            const double pang_yaw = -atan(px / pz);
+            const double pang_pitch = asin(py / pl);
+
+            const double ang_yaw = panostate->getAngX();
+            const double ang_pitch = panostate->getAngY();
+
+            const double x = sin(ang_yaw) * cos(ang_pitch);
+            const double z = cos(ang_yaw) * cos(ang_pitch);
+            const double y = sin(ang_pitch);
+
+            const Vector3 vec(x, y, z);
+
+            const Vector3 top(0, 1, 0);
+
+            const Vector3 ptop = vec.Cross(top).Cross(vec).GetNormalized();
+
+            Vector3 tres;
+            tres.x = ptop.x * (ptop.x * vec.x + ptop.y * vec.y + ptop.z * vec.z) + cos(pang_yaw) * (ptop.x * (-ptop.y * vec.y - ptop.z * vec.z) + vec.x * (ptop.y * ptop.y + ptop.z * ptop.z)) + sin(pang_yaw) * (-ptop.z * vec.y + ptop.y * vec.z);
+            tres.y = ptop.y * (ptop.x * vec.x + ptop.y * vec.y + ptop.z * vec.z) + cos(pang_yaw) * (ptop.y * (-ptop.x * vec.x - ptop.z * vec.z) + vec.y * (ptop.x * ptop.x + ptop.z * ptop.z)) + sin(pang_yaw) * (-ptop.z * vec.x + ptop.x * vec.z);
+            tres.z = ptop.z * (ptop.x * vec.x + ptop.y * vec.y + ptop.z * vec.z) + cos(pang_yaw) * (ptop.z * (-ptop.x * vec.x - ptop.y * vec.y) + vec.z * (ptop.x * ptop.x + ptop.y * ptop.y)) + sin(pang_yaw) * (-ptop.y * vec.x + ptop.x * vec.y);
+
+            const Vector3 pside = ptop.Cross(tres).GetNormalized();
+            Vector3 res;
+
+            res.x = pside.x * (pside.x * tres.x + pside.y * tres.y + pside.z * tres.z) + cos(pang_pitch) * (pside.x * (-pside.y * tres.y - pside.z * tres.z) + tres.x * (pside.y * pside.y + pside.z * pside.z)) + sin(pang_pitch) * (-pside.z * tres.y + pside.y * tres.z);
+            res.y = pside.y * (pside.x * tres.x + pside.y * tres.y + pside.z * tres.z) + cos(pang_pitch) * (pside.y * (-pside.x * tres.x - pside.z * tres.z) + tres.y * (pside.x * pside.x + pside.z * pside.z)) + sin(-pang_pitch) * (-pside.z * tres.x + pside.x * tres.z);
+            res.z = pside.z * (pside.x * tres.x + pside.y * tres.y + pside.z * tres.z) + cos(pang_pitch) * (pside.z * (-pside.x * tres.x - pside.y * tres.y) + tres.z * (pside.x * pside.x + pside.y * pside.y)) + sin(pang_pitch) * (-pside.y * tres.x + pside.x * tres.y);
+
+            double yaw, pitch;
+            pitch = asin(res.y);
+            yaw = atan2(res.x, res.z);
+
+            yaw += M_PI / 2.0;
+            if (yaw < 0) yaw += 2 * M_PI;
+            if (yaw > 2 * M_PI) yaw -= 2 * M_PI;
+
+            pitch += M_PI / 2.0;
+            pitch = M_PI - pitch;
+
+            mouse_pano_x = yaw / (2 * M_PI) * panostate->GetOptions()->getWidth();
+            mouse_pano_y = pitch / (M_PI)*panostate->GetOptions()->getHeight();
+
+            ////        cerr << "mouse " << RAD_TO_DEG(yaw) << " " << RAD_TO_DEG(pitch) << " " << " ; " << RAD_TO_DEG(pang_yaw) << " " << RAD_TO_DEG(pang_pitch) << " ; " << RAD_TO_DEG(ang_yaw) << " " << RAD_TO_DEG(ang_pitch) << " ; " << px << " " << py << " " << pz << " ; " << ax << " " << ay);
+            //        cerr << "mouse " << mouse_pano_x << " " << mouse_pano_y << " ; " << canv_w << " " << canv_h);
+            //        double t_mouse_pano_x = yaw M
+        }
+        else
+        {
+            mouse_over_pano = false;
+        };
+    };
     
     ToolHelper::MouseMoved(x,y,e);
 }
@@ -773,34 +771,5 @@ void PlaneOverviewToolHelper::MouseMoved(int x, int y, wxMouseEvent & e)
     ToolHelper::MouseMoved(x,y,e);
 }
 
-void PlaneOverviewToolHelper::UpdateImagesUnderMouse()
-{
-    images_under_mouse.clear();
-    if (IsMouseOverPano()) {
-        unsigned int num_images = pano->getNrOfImages();
-        std::set<unsigned int> displayedImages = pano->getActiveImages();
-        for (unsigned int image_index = 0; image_index < num_images; image_index++)
-        {
-            // don't try any images that are turned off
-            if (displayedImages.count(image_index))
-            {
-                // work out if the image covers the point under the mouse.
-                HuginBase::PTools::Transform transform;
-                transform.createTransform(*visualization_state->GetSrcImage(image_index),
-                                          *visualization_state->GetOptions());
-                double image_x, image_y;
-                transform.transformImgCoord(image_x, image_y, mouse_pano_x, mouse_pano_y);
-                if (visualization_state->getViewState()->GetSrcImage(image_index)->isInside(vigra::Point2D(
-                                                      int(image_x), int (image_y))))
-                {
-                    // this image is under the mouse, add it to the set.
-                    images_under_mouse.insert(image_index);
-                }
-            }
-        }
-    }
-    images_under_mouse_current = true;
-
-}
 
 
