@@ -134,7 +134,8 @@ public:
     void SetStatusMessage(wxString message);
 
     bool IsMouseOverPano() {return mouse_over_pano;}
-    
+    // return set of images under given position
+    HuginBase::UIntSet GetImagesUnderPos(const hugin_utils::FDiff2D& pos);
     GLPreviewFrame * GetPreviewFrame() {return frame;}
     
 protected:
@@ -175,7 +176,7 @@ protected:
     bool images_under_mouse_current, mouse_over_pano;
     // which images are under the mouse?
     std::set<unsigned int> images_under_mouse;
-    virtual void UpdateImagesUnderMouse() = 0;
+    void UpdateImagesUnderMouse();
     void InvalidateImagesUnderMouse();
 };
 
@@ -188,7 +189,6 @@ public:
     ~PreviewToolHelper() {}
 
     void MouseMoved(int x, int y, wxMouseEvent & e);
-    void UpdateImagesUnderMouse();
 
 };
 
@@ -219,7 +219,6 @@ public:
     void DoNotNotifyMe(PanosphereOverviewEvent event, PanosphereOverviewTool *tool);
 
     void MouseMoved(int x, int y, wxMouseEvent & e);
-    void UpdateImagesUnderMouse();
 
     void BeforeDrawImagesBack();
     void BeforeDrawImagesFront();
@@ -246,8 +245,7 @@ public:
     ~PlaneOverviewToolHelper();
 
     void MouseMoved(int x, int y, wxMouseEvent & e);
-    void UpdateImagesUnderMouse();
-    
+
     double getPlaneX() {return plane_x;}
     double getPlaneY() {return plane_y;}
 
