@@ -89,22 +89,22 @@ void Batch::AddAppToBatch(wxString app)
     m_projList.Add(newApp);
 }
 
-void Batch::AddProjectToBatch(wxString projectFile, wxString outputFile,Project::Target target)
+void Batch::AddProjectToBatch(wxString projectFile, wxString outputFile, wxString userDefinedSequence, Project::Target target)
 {
     wxFileName projectName(projectFile);
     wxFileName outName(outputFile);
-    projectName.Normalize(wxPATH_NORM_ALL & ~wxPATH_NORM_ENV_VARS);
-    outName.Normalize(wxPATH_NORM_ALL & ~wxPATH_NORM_ENV_VARS);
+    projectName.Normalize(wxPATH_NORM_ABSOLUTE | wxPATH_NORM_DOTS | wxPATH_NORM_TILDE | wxPATH_NORM_SHORTCUT);
+    outName.Normalize(wxPATH_NORM_ABSOLUTE | wxPATH_NORM_DOTS | wxPATH_NORM_TILDE | wxPATH_NORM_SHORTCUT);
 
-    if(outputFile.Cmp(_T(""))!=0 || target==Project::DETECTING)
+    if(!outputFile.IsEmpty() || target==Project::DETECTING)
     {
-        Project* proj = new Project(projectName.GetFullPath(),outName.GetFullPath(),target);
+        Project* proj = new Project(projectName.GetFullPath(), outName.GetFullPath(), userDefinedSequence, target);
         m_projList.Add(proj);
     }
     else
     {
         //on output set as "", it defaults to same path and name as project file
-        Project* proj = new Project(projectName.GetFullPath(),wxT(""));
+        Project* proj = new Project(projectName.GetFullPath(), wxEmptyString, userDefinedSequence);
         m_projList.Add(proj);
     }
 }
@@ -125,92 +125,72 @@ bool Batch::AllDone()
 
 void Batch::AppendBatchFile(wxString file)
 {
-    wxFileName aFile(file);
-    if(aFile.FileExists())
+    if (wxFileName::FileExists(file))
     {
         wxFileInputStream fileStream(file);
-        wxString projectName = _T("");
-#ifdef __WXMSW__
-        wxTextInputStream textStream(fileStream, wxT(" \t"), wxConvLocal);
-#else
-        wxTextInputStream textStream(fileStream);
-#endif
-
-        //TO-DO: batch file error checking?
+        wxFileConfig batchFile(fileStream);
         //first line in file is idGenerator, we save it a temp variable, cause it gets set when adding projects
-        long idGenTemp = 1;
-        if (fileStream.Eof())
-        {
-            return;
-        };
-        textStream.ReadLine().ToLong(&idGenTemp);
+        const long idGenTemp = batchFile.ReadLong("/Main/CurrentID", 1l);
+        const long projCount = batchFile.ReadLong("/Main/Count", 0l);
         //then for each project: project path, prefix, id, status, skip
-        if (fileStream.Eof())
+        if (projCount > 0)
         {
-            return;
-        };
-        while((projectName = textStream.ReadLine()).Cmp(wxT(""))!=0)
-        {
-            // read all line, check before reading
-            if (fileStream.Eof())
+            // we can not use GetFirstGroup/GetNextGroup because these function return the groups in alphabetical order
+            // and not in the order in the file
+            for (long i = 1; i <= projCount; ++i)
             {
-                break;
-            };
-            wxString line=textStream.ReadLine();
-            if (fileStream.Eof())
-            {
-                break;
-            };
-            long id;
-            textStream.ReadLine().ToLong(&id);
-            long status;
-            if (fileStream.Eof())
-            {
-                break;
-            };
-            textStream.ReadLine().ToLong(&status);
-            if (fileStream.Eof())
-            {
-                break;
-            };
-            const bool skip = textStream.ReadLine().StartsWith(_T("T"));
+                const wxString group = wxString::Format("Project_%ld", i);
+                if (batchFile.HasGroup(group))
+                {
+                    batchFile.SetPath(group);
+                    const wxString projectName = batchFile.Read("Project", wxEmptyString);
+                    const wxString type = batchFile.Read("Type", "Stitching");
+                    const long id = batchFile.ReadLong("Id", 1);
+                    long status = batchFile.ReadLong("Status", (long)Project::WAITING);
+                    const bool skip = batchFile.ReadBool("Skip", false);
 
-            //we add project to internal list
-            if (id == -1)
-            {
-                AddAppToBatch(projectName);
-            }
-            else
-            {
-                if (line.IsEmpty())
-                {
-                    AddProjectToBatch(projectName, wxT(""), Project::DETECTING);
-                }
-                else
-                {
-                    AddProjectToBatch(projectName, line);
+                    //we add project to internal list
+                    if (id < 0)
+                    {
+                        // negative ID means command
+                        AddAppToBatch(projectName);
+                    }
+                    else
+                    {
+                        const wxString userDefinedSequence = batchFile.Read("UserDefinedSequence", wxEmptyString);
+                        if (type.CmpNoCase("Stitching") == 0)
+                        {
+                            const wxString prefix = batchFile.Read("Prefix", wxEmptyString);
+                            AddProjectToBatch(projectName, prefix, userDefinedSequence);
+                        }
+                        else
+                        {
+                            if (type.CmpNoCase("Detecting") == 0)
+                            {
+                                AddProjectToBatch(projectName, wxEmptyString, userDefinedSequence, Project::DETECTING);
+                            }
+                            else
+                            {
+                                //unknow type, skipping
+                                continue;
+                            };
+                        };
+                    };
+                    //if status was RUNNING or PAUSED, we set it to FAILED
+                    if (status == (long)Project::RUNNING || status == (long)Project::PAUSED)
+                    {
+                        status = (long)Project::FAILED;
+                    }
+                    m_projList.Last().id = id;
+                    m_projList.Last().status = (Project::Status)status;
+                    m_projList.Last().skip = batchFile.ReadBool("Skip", false);
+                    batchFile.SetPath("/");
                 };
             };
-            //if status was RUNNING or PAUSED, we set it to FAILED
-            if(status==(long)Project::RUNNING || status==(long)Project::PAUSED)
-            {
-                status=(long)Project::FAILED;
-            }
-            m_projList.Last().id = id;
-            m_projList.Last().status = (Project::Status)status;
-            if(skip)
-            {
-                m_projList.Last().skip = true;
-            };
-
-            if (fileStream.Eof())
-            {
-                break;
-            };
-        }
+        };
         //we set the id generator we got from file
         Project::idGenerator = idGenTemp;
-    }
+    };
 }
 
 void Batch::CancelBatch()
@@ -247,6 +227,11 @@ void Batch::ChangePrefix(int index, wxString newPrefix)
     m_projList.Item(index).prefix = newPrefix;
 }
 
+void Batch::ChangeUserDefined(int index, wxString newUserDefined)
+{
+    m_projList.Item(index).userDefindSequence = newUserDefined;
+}
+
 int Batch::ClearBatch()
 {
     if(m_stitchFrames.GetCount()!=0)
@@ -396,11 +381,11 @@ int Batch::LoadBatchFile(wxString file)
 
 int Batch::LoadTemp()
 {
-    const wxFileName batchQueue(wxStandardPaths::Get().GetUserConfigDir(), _T(".ptbt"));
+    wxString batchQueue = GetBatchFilename();
     //we load the data from the temp file
-    if (batchQueue.FileExists())
+    if (wxFileName::FileExists(batchQueue))
     {
-        AppendBatchFile(batchQueue.GetFullPath());
+        AppendBatchFile(batchQueue);
     };
     return 0;
 }
@@ -486,7 +471,7 @@ void Batch::OnProcessTerminate(wxProcessEvent& event)
                 if(autostitch && m_projList.Item(i).target==Project::DETECTING)
                 {
                     wxFileName name(m_projList.Item(i).path);
-                    AddProjectToBatch(m_projList.Item(i).path,name.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR) + name.GetName(),Project::STITCHING);
+                    AddProjectToBatch(m_projList.Item(i).path,name.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR) + name.GetName(), wxEmptyString, Project::STITCHING);
                     notifyParent=true;
                 };
                 if(autoremove)
@@ -614,7 +599,7 @@ void Batch::OnProcessTerminate(wxProcessEvent& event)
     }
 }
 
-bool Batch::OnStitch(wxString scriptFile, wxString outname, int id)
+bool Batch::OnStitch(wxString scriptFile, wxString outname, wxString userDefinedOutput, int id)
 {
     // delete the existing wxConfig to force reloading of settings from file/registy
     delete wxConfigBase::Set((wxConfigBase*)NULL);
@@ -684,7 +669,7 @@ bool Batch::OnStitch(wxString scriptFile, wxString outname, int id)
         stitchFrame->m_stitchPanel->SetOverwrite(true);
     }
 
-    bool n = stitchFrame->StitchProject(scriptFile, outname);
+    bool n = stitchFrame->StitchProject(scriptFile, outname, userDefinedOutput);
     if(n)
     {
         m_stitchFrames.Add(stitchFrame);
@@ -697,7 +682,7 @@ bool Batch::OnStitch(wxString scriptFile, wxString outname, int id)
 
 }
 
-bool Batch::OnDetect(wxString scriptFile, int id)
+bool Batch::OnDetect(wxString scriptFile, wxString userDefinedAssistant, int id)
 {
     // delete the existing wxConfig to force reloading of settings from file/registy
     delete wxConfigBase::Set((wxConfigBase*)NULL);
@@ -712,7 +697,7 @@ bool Batch::OnDetect(wxString scriptFile, int id)
     wxFileName basename(scriptFile);
     stitchFrame->SetTitle(wxString::Format(_("%s - Assistant"), basename.GetName().c_str()));
 
-    bool n = stitchFrame->DetectProject(scriptFile);
+    bool n = stitchFrame->DetectProject(scriptFile, userDefinedAssistant);
     if(n)
     {
         m_stitchFrames.Add(stitchFrame);
@@ -841,6 +826,16 @@ void Batch::RunNextInBatch()
                 // skip non-existing project files
                 continue;
             };
+            if (!m_projList.Item(i).userDefindSequence.empty())
+            {
+                // skip non-existing user defined sequence files
+                if (!wxFileName::FileExists(m_projList.Item(i).userDefindSequence))
+                {
+                    m_projList.Item(i).status = Project::MISSING;
+                    m_projList.Item(i).skip = true;
+                    continue;
+                };
+            }
             m_projList.Item(i).status=Project::RUNNING;
             m_running = true;
             if(m_projList.Item(i).target==Project::STITCHING)
@@ -848,14 +843,14 @@ void Batch::RunNextInBatch()
                 wxCommandEvent e(EVT_INFORMATION,wxID_ANY);
                 e.SetString(wxString::Format(_("Now stitching: %s"),m_projList.Item(i).path.c_str()));
                 GetParent()->GetEventHandler()->AddPendingEvent(e);
-                value = OnStitch(m_projList.Item(i).path, m_projList.Item(i).prefix, m_projList.Item(i).id);
+                value = OnStitch(m_projList.Item(i).path, m_projList.Item(i).prefix, m_projList.Item(i).userDefindSequence, m_projList.Item(i).id);
             }
             else
             {
                 wxCommandEvent e(EVT_INFORMATION,wxID_ANY);
                 e.SetString(wxString::Format(_("Now detecting: %s"),m_projList.Item(i).path.c_str()));
                 GetParent()->GetEventHandler()->AddPendingEvent(e);
-                value = OnDetect(m_projList.Item(i).path,m_projList.Item(i).id);
+                value = OnDetect(m_projList.Item(i).path, m_projList.Item(i).userDefindSequence, m_projList.Item(i).id);
             };
             if(!value)
             {
@@ -875,50 +870,56 @@ void Batch::RunNextInBatch()
 
 void Batch::SaveBatchFile(wxString file)
 {
-    wxFileOutputStream fileStream(file);
-#ifdef __WXMSW__
-    wxTextOutputStream textStream(fileStream, wxEOL_NATIVE, wxConvLocal);
-#else
-    wxTextOutputStream textStream(fileStream);
-#endif
+    wxFileConfig batchFile;
     //we write current idGenerator to file
-    wxString line = _T("");
-    line << Project::idGenerator;
-    textStream.WriteString(line+_T("\n"));
+    batchFile.Write("/Main/CurrentID", Project::idGenerator);
+    batchFile.Write("/Main/Count", m_projList.GetCount());
     //then for each project: project path, prefix, id, status, skip
-    for(unsigned int i = 0; i< m_projList.GetCount(); i++)
+    for (unsigned int i = 0; i < m_projList.GetCount(); i++)
     {
-        textStream.WriteString(m_projList.Item(i).path+_T("\n"));
-        if(m_projList.Item(i).target==Project::STITCHING)
+        batchFile.SetPath(wxString::Format("/Project_%u", i + 1));
+        batchFile.Write("Project", m_projList.Item(i).path);
+        switch (m_projList.Item(i).target)
         {
-            textStream.WriteString(m_projList.Item(i).prefix+_T("\n"));
-        }
-        else
-        {
-            textStream.WriteString(_T("\n"));
+            case Project::STITCHING:
+                batchFile.Write("Type", "Stitching");
+                batchFile.Write("Prefix", m_projList.Item(i).prefix);
+                break;
+            case Project::DETECTING:
+                batchFile.Write("Type", "Detecting");
+                break;
         };
-        line = _T("");
-        line << m_projList.Item(i).id;
-        textStream.WriteString(line+_T("\n"));
-        line = _T("");
-        line << m_projList.Item(i).status;
-        textStream.WriteString(line+_T("\n"));
-        if(m_projList.Item(i).skip)
+        if (!m_projList.Item(i).userDefindSequence.IsEmpty())
         {
-            textStream.WriteString(_T("T\n"));
-        }
-        else
+            batchFile.Write("UserDefinedSequence", m_projList.Item(i).userDefindSequence);
+        };
+        batchFile.Write("Id", m_projList.Item(i).id);
+        batchFile.Write("Status", (long)m_projList.Item(i).status);
+        if (m_projList.Item(i).skip)
         {
-            textStream.WriteString(_T("F\n"));
-        }
-    }
+            batchFile.Write("Skip", m_projList.Item(i).skip);
+        };
+    };
+    wxFileOutputStream fileStream(file);
+    batchFile.Save(fileStream);
     fileStream.Close();
 }
 
+wxString Batch::GetBatchFilename()
+{
+    wxString userDataDir = wxString(hugin_utils::GetUserAppDataDir().c_str(), wxConvLocal);
+    if (userDataDir.IsEmpty())
+    {
+        // could not find user data directory, or this directory could not be create
+        // fall back to system user data dir
+        userDataDir = wxStandardPaths::Get().GetUserConfigDir();
+    }
+    return wxFileName(userDataDir, _T("PTBatcherQueue.ptq")).GetFullPath();
+}
+
 void Batch::SaveTemp()
 {
-    const wxFileName batchQueue(wxStandardPaths::Get().GetUserConfigDir(), _T(".ptbt"));
-    SaveBatchFile(batchQueue.GetFullPath());
+    SaveBatchFile(GetBatchFilename());
 }
 
 void Batch::SetStatus(int index,Project::Status status)
