@@ -72,7 +72,7 @@ public:
     /** Adds an application entry in the batch list */
     void  AddAppToBatch(wxString app);
     /** Adds a project entry in the batch list */
-    void  AddProjectToBatch(wxString projectFile, wxString outputFile = _T(""), Project::Target target=Project::STITCHING);
+    void  AddProjectToBatch(wxString projectFile, wxString outputFile = wxEmptyString, wxString userDefinedSequence = wxEmptyString, Project::Target target = Project::STITCHING);
     /** Returns true if there are no more projects pending execution */
     bool  AllDone();
     /** Appends projects from file to batch list */
@@ -83,6 +83,8 @@ public:
     void  CancelProject(int index);
     /** Changes output prefix for project at index */
     void  ChangePrefix(int index, wxString newPrefix);
+    /** Changes user defined sequence for project at index */
+    void ChangeUserDefined(int index, wxString newUserDefined);
     /** Clears batch list and returns 0 if succesful */
     int   ClearBatch();
     /** Compares two project at indexes in both lists and returns true if they have identical project ids */
@@ -114,9 +116,9 @@ public:
     /** Called internally when all running processes have completed and need to be removed from running list */
     void  OnProcessTerminate(wxProcessEvent& event);
     /** Called to start stitch of project with input scriptFile */
-    bool  OnStitch(wxString scriptFile, wxString outname, int id);
+    bool  OnStitch(wxString scriptFile, wxString outname, wxString userDefinedOutput, int id);
     /** called to start detecting */
-    bool OnDetect(wxString scriptFile, int id);
+    bool OnDetect(wxString scriptFile, wxString userDefinedAssistant, int id);
     /** Pauses and continues batch execution */
     void  PauseBatch();
     /** Removes project with id from batch list */
@@ -129,6 +131,8 @@ public:
     void  RunNextInBatch();
     /** Saves batch list to file */
     void  SaveBatchFile(wxString file);
+    /** returns the filename of the default queue file */
+    wxString GetBatchFilename();
     /** Saves batch list to temporary file */
     void  SaveTemp();
     /** Used internally to set status of selected project */
