@@ -69,12 +69,15 @@ public:
     void OnButtonAddCommand(wxCommandEvent& event);
     void OnButtonAddDir(wxCommandEvent& event);
     void OnButtonSearchPano(wxCommandEvent& e);
+    /** generate a sequence of panoramas */
+    void OnButtonGenerateSequence(wxCommandEvent& e);
     /** let the user select a project file which should be added to the stitching queue */
     void OnButtonAddToStitchingQueue(wxCommandEvent& event);
     /** let the user select a project file which should be added to the stitching queue */
     void OnButtonAddToAssistantQueue(wxCommandEvent& event);
     void OnButtonCancel(wxCommandEvent& event);
     void OnButtonChangePrefix(wxCommandEvent& event);
+    void OnButtonChangeUserDefinedSequence(wxCommandEvent& event);
     void OnButtonClear(wxCommandEvent& event);
     void OnMinimizeTrayMenu(wxCommandEvent& e);
     void OnButtonHelp(wxCommandEvent& event);
@@ -131,9 +134,11 @@ public:
     /** return if always save log is checked */
     bool GetCheckSaveLog();
     void RestoreSize();
-    void AddToList(wxString aFile, Project::Target target=Project::STITCHING);
+    void AddToList(wxString aFile, Project::Target target=Project::STITCHING, wxString userDefined = wxEmptyString);
+    void AddArrayToList(const wxArrayString& fileList, Project::Target target);
     void AddDirToList(wxString aDir);
     void ChangePrefix(int index,wxString newPrefix);
+    void ChangeUserDefined(int index, wxString newUserDefined);
     /** returns true, if batch is running */
     bool IsRunning();
     /** returns true, if batch is paused */
