@@ -55,11 +55,7 @@ class BatchIPCConnection : public wxConnection
 {
 public:
     /** request handler for transfer */
-#if wxCHECK_VERSION(2,9,0)
     virtual const void* OnRequest(const wxString& topic, const wxString& item, size_t* size = NULL, wxIPCFormat format = wxIPC_TEXT);
-#else
-    virtual wxChar* OnRequest(const wxString& topic, const wxString& item, int* size = NULL, wxIPCFormat format = wxIPC_TEXT);
-#endif
 };
 
 /** server which implements the communication between different PTBatcherGUI instances (see BatchIPCConnection) */
@@ -94,7 +90,6 @@ public:
 
     //Handles some input keys for the frame
     void OnItemActivated(wxListEvent& event);
-    void OnKeyDown(wxKeyEvent& event);
 
     //Main batch list
     ProjectArray projList;
@@ -106,9 +101,8 @@ public:
     };
 
 #ifdef __WXMAC__
-    /** the wx calls this method when the app gets "Open file" AppleEvent */
-    // see comment in PTBatchGUI.cpp
-    // void MacOpenFile(const wxString& fileName);
+    /** the wx calls this method when the app gets "Open files" AppleEvent */
+    void MacOpenFiles(const wxArrayString &fileNames);
 #endif
 
 private:
@@ -118,10 +112,6 @@ private:
     wxSingleInstanceChecker* m_checker;
     BatchIPCServer* m_server;
 
-#ifdef __WXMAC__
-    wxString m_macFileNameToOpenOnStart;
-#endif
-
     DECLARE_EVENT_TABLE()
 };
 
