@@ -34,7 +34,8 @@ enum
     ID_CHANGE_PREFIX=wxID_HIGHEST+200,
     ID_RESET_PROJECT=wxID_HIGHEST+201,
     ID_EDIT_PROJECT=wxID_HIGHEST+202,
-    ID_REMOVE_PROJECT=wxID_HIGHEST+203
+    ID_REMOVE_PROJECT=wxID_HIGHEST+203,
+    ID_CHANGE_USER_DEFINED=wxID_HIGHEST+204
 };
 
 BEGIN_EVENT_TABLE(ProjectListBox, wxListCtrl)
@@ -44,6 +45,8 @@ BEGIN_EVENT_TABLE(ProjectListBox, wxListCtrl)
     EVT_MENU(ID_RESET_PROJECT, ProjectListBox::OnResetProject)
     EVT_MENU(ID_EDIT_PROJECT, ProjectListBox::OnEditProject)
     EVT_MENU(ID_REMOVE_PROJECT, ProjectListBox::OnRemoveProject)
+    EVT_MENU(ID_CHANGE_USER_DEFINED, ProjectListBox::OnChangeUserDefined)
+    EVT_CHAR(ProjectListBox::OnChar)
 END_EVENT_TABLE()
 
 bool ProjectListBox::Create(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style, const wxString& name)
@@ -52,14 +55,15 @@ bool ProjectListBox::Create(wxWindow* parent, wxWindowID id, const wxPoint& pos,
     {
         return false;
     };
-    columns.Add(ID),
-                columns.Add(PROJECT);
+    columns.Add(ID);
+    columns.Add(PROJECT);
     columns.Add(PREFIX);
     columns.Add(STATUS);
     columns.Add(MODDATE);
     columns.Add(FORMAT);
     columns.Add(PROJECTION);
     columns.Add(SIZE);
+    columns.Add(USERDEFINEDSEQUENCE);
 
     this->InsertColumn(0,_("ID"));
     this->InsertColumn(1,_("Project"));
@@ -69,6 +73,7 @@ bool ProjectListBox::Create(wxWindow* parent, wxWindowID id, const wxPoint& pos,
     this->InsertColumn(5,_("Output format"));
     this->InsertColumn(6,_("Projection"));
     this->InsertColumn(7,_("Size"));
+    this->InsertColumn(8, _("User defined sequence"));
 
     //get saved width
     for( int i=0; i < GetColumnCount() ; i++ )
@@ -134,6 +139,16 @@ void ProjectListBox::ChangePrefix(int index, wxString newPrefix)
     }
 }
 
+void ProjectListBox::ChangeUserDefined(int index, wxString newUserDefined)
+{
+    int colIndex = columns.Index(USERDEFINEDSEQUENCE);
+    if (colIndex != wxNOT_FOUND)
+    {
+        Project* project = m_batch->GetProject(index);
+        this->SetItem(index, colIndex, this->GetAttributeString(colIndex, project));
+    }
+}
+
 void ProjectListBox::Deselect(int index)
 {
     SetItemState(index, 0, wxLIST_STATE_SELECTED|wxLIST_STATE_FOCUSED);
@@ -232,7 +247,7 @@ void ProjectListBox::SetMissing(int index)
         {
             this->SetItem(index,i,_("File missing"));
         }
-        if(columns[i]!=ID && columns[i]!=PROJECT && columns[i]!=PREFIX)
+        if(columns[i]!=ID && columns[i]!=PROJECT && columns[i]!=PREFIX && columns[i]!=USERDEFINEDSEQUENCE)
         {
             this->SetItem(index,i,_T(""));
         }
@@ -337,6 +352,12 @@ wxString ProjectListBox::GetAttributeString(int i, Project* project)
                 return str;
             }
             return wxEmptyString;
+        case 8:
+            if (!project->userDefindSequence.IsEmpty())
+            {
+                return project->userDefindSequence;
+            };
+            return wxEmptyString;
         default:
             return _T("");
     }
@@ -376,29 +397,83 @@ void ProjectListBox::OnColumnWidthChange(wxListEvent& event)
 void ProjectListBox::OnContextMenu(wxContextMenuEvent& e)
 {
     const HuginBase::UIntSet selected(GetSelectedProjects());
+    wxPoint point = e.GetPosition();
+    // if from keyboard
+    if ((point.x == -1) && (point.y == -1))
+    {
+        wxSize size = GetSize();
+        point.x = size.x / 2;
+        point.y = size.y / 2;
+    }
+    else
+    {
+        point = ScreenToClient(point);
+    };
     if (selected.size() == 1)
     {
-        wxPoint point = e.GetPosition();
-        // if from keyboard
-        if((point.x==-1) && (point.y==-1))
-        {
-            wxSize size = GetSize();
-            point.x = size.x / 2;
-            point.y = size.y / 2;
-        }
-        else
-        {
-            point = ScreenToClient(point);
-        }
         wxMenu menu;
         menu.Append(ID_CHANGE_PREFIX, _("Change prefix"));
+        menu.Append(ID_CHANGE_USER_DEFINED, _("Change user defined sequence"));
         menu.Append(ID_RESET_PROJECT, _("Reset project"));
         menu.Append(ID_EDIT_PROJECT, _("Edit with Hugin"));
         menu.Append(ID_REMOVE_PROJECT, _("Remove"));
         PopupMenu(&menu, point.x, point.y);
+    }
+    else
+    {
+        if (selected.size() > 1)
+        {
+            wxMenu menu;
+            // check that all selected project have the same target
+            const Project::Target target = m_batch->GetProject(*(selected.begin()))->target;
+            bool isSameTarget = true;
+            for (const auto& i : selected)
+            {
+                if (m_batch->GetProject(i)->target != target)
+                {
+                    isSameTarget = false;
+                    break;
+                };
+            };
+            if (isSameTarget)
+            {
+                menu.Append(ID_CHANGE_USER_DEFINED, _("Change user defined sequence"));
+            };
+            menu.Append(ID_RESET_PROJECT, _("Reset project"));
+            menu.Append(ID_REMOVE_PROJECT, _("Remove"));
+            PopupMenu(&menu, point.x, point.y);
+        };
     };
 };
 
+void ProjectListBox::OnChar(wxKeyEvent& e)
+{
+    switch (e.GetKeyCode())
+    {
+        case WXK_DELETE:
+        case WXK_NUMPAD_DELETE:
+            {
+                wxCommandEvent ev(wxEVT_TOOL, XRCID("tool_remove"));
+                GetParent()->GetEventHandler()->AddPendingEvent(ev);
+            };
+            break;
+        case WXK_INSERT:
+        case WXK_NUMPAD_INSERT:
+            {
+                wxCommandEvent ev(wxEVT_MENU, XRCID("menu_add"));
+                GetParent()->GetEventHandler()->AddPendingEvent(ev);
+            };
+            break;
+        case WXK_ESCAPE:
+            {
+                wxCommandEvent ev(wxEVT_TOOL, XRCID("tool_cancel"));
+                GetParent()->GetEventHandler()->AddPendingEvent(ev);
+            };
+            break;
+        default:
+            e.Skip();
+    };
+}
 void ProjectListBox::OnChangePrefix(wxCommandEvent& e)
 {
     wxCommandEvent ev(wxEVT_COMMAND_BUTTON_CLICKED, XRCID("button_prefix"));
@@ -423,6 +498,12 @@ void ProjectListBox::OnRemoveProject(wxCommandEvent& e)
     GetParent()->GetEventHandler()->AddPendingEvent(ev);
 };
 
+void ProjectListBox::OnChangeUserDefined(wxCommandEvent& e)
+{
+    wxCommandEvent ev(wxEVT_COMMAND_BUTTON_CLICKED, XRCID("button_user_defined"));
+    GetParent()->GetEventHandler()->AddPendingEvent(ev);
+}
+
 const wxString ProjectListBox::fileFormat[] = {_T("JPEG"),
         _T("JPEG_m"),
         _T("PNG"),
