@@ -132,9 +132,9 @@ void RunStitchFrame::OnProcessTerminate(wxProcessEvent& event)
     }
 }
 
-bool RunStitchFrame::StitchProject(wxString scriptFile, wxString outname)
+bool RunStitchFrame::StitchProject(wxString scriptFile, wxString outname, wxString userDefinedOutput)
 {
-    if (! m_stitchPanel->StitchProject(scriptFile, outname))
+    if (! m_stitchPanel->StitchProject(scriptFile, outname, userDefinedOutput))
     {
         return false;
     }
@@ -143,9 +143,9 @@ bool RunStitchFrame::StitchProject(wxString scriptFile, wxString outname)
     return true;
 }
 
-bool RunStitchFrame::DetectProject(wxString scriptFile)
+bool RunStitchFrame::DetectProject(wxString scriptFile, wxString userDefinedAssistant)
 {
-    if (! m_stitchPanel->DetectProject(scriptFile))
+    if (! m_stitchPanel->DetectProject(scriptFile, userDefinedAssistant))
     {
         return false;
     }
