@@ -46,9 +46,9 @@ public:
     RunStitchFrame(wxWindow* parent, const wxString& title, const wxPoint& pos, const wxSize& size);  //ProjectArray projList, wxListBox *projListBox);
 
     /** Starts stitching of project file */
-    bool StitchProject(wxString scriptFile, wxString outname);
+    bool StitchProject(wxString scriptFile, wxString outname, wxString userDefinedOutput = wxEmptyString);
     /** starts assistant of project file */
-    bool DetectProject(wxString scriptFile);
+    bool DetectProject(wxString scriptFile, wxString userDefinedAssistant = wxEmptyString);
     /** Returns process ID of running process */
     int GetProcessId();
     /** Gets project id from batch */
