@@ -24,8 +24,12 @@
 
 #include "CalculateOptimalROI.h"
 #include <algorithm>
+#include "LayerStacks.h"
+#include "algorithms/nona/ComputeImageROI.h"
 
 namespace HuginBase {
+// uncomment the follow line to print more progress
+//#define PRINT_DEBUG_VALUES
 
 ///
 bool CalculateOptimalROI::calcOptimalROI(PanoramaData& panorama)
@@ -35,6 +39,19 @@ bool CalculateOptimalROI::calcOptimalROI(PanoramaData& panorama)
     {
         return false;
     };
+    // check that all images are visible
+    const HuginBase::UIntSet visibleImages = HuginBase::getImagesinROI(panorama, activeImages, vigra::Rect2D(vigra::Point2D(0, 0), panorama.getOptions().getSize()));
+    if (visibleImages.size() != activeImages.size())
+    {
+        // ignore invisible images
+        HuginBase::UIntSet updatedImages;
+        std::set_intersection(activeImages.begin(), activeImages.end(), visibleImages.begin(), visibleImages.end(), std::inserter(updatedImages, updatedImages.begin()));
+        activeImages = updatedImages;
+        if (activeImages.empty())
+        {
+            return false;
+        };
+    };
 
     PanoramaOptions opt = panorama.getOptions();
     o_optimalSize=opt.getSize();
@@ -45,8 +62,8 @@ bool CalculateOptimalROI::calcOptimalROI(PanoramaData& panorama)
     m_bestRect = vigra::Rect2D();
     try
     {
-        testedPixels.resize(o_optimalSize.x*o_optimalSize.y,false);
-        pixels.resize(o_optimalSize.x*o_optimalSize.y,false);
+        testedPixels.resize(static_cast<long long>(o_optimalSize.x) * o_optimalSize.y,false);
+        pixels.resize(static_cast<long long>(o_optimalSize.x) * o_optimalSize.y,false);
     }
     catch(std::bad_alloc&)
     {
@@ -119,7 +136,7 @@ bool CalculateOptimalROI::stackPixel(int i, int j, UIntSet &stack)
 
 bool CalculateOptimalROI::imgPixel(int i, int j)
 {
-    if(!testedPixels[j*o_optimalSize.x+i])
+    if(!testedPixels[static_cast<long long>(j) * o_optimalSize.x + i])
     {
         bool inside;
         
@@ -143,15 +160,15 @@ bool CalculateOptimalROI::imgPixel(int i, int j)
             }
         }
 
-        testedPixels[j*o_optimalSize.x + i] = true;
-        pixels[j*o_optimalSize.x + i] = inside;
+        testedPixels[static_cast<long long>(j) * o_optimalSize.x + i] = true;
+        pixels[static_cast<long long>(j) * o_optimalSize.x + i] = inside;
         
         return inside;
     }
     //else it is know if this pixel is covered by at least one image
     else
     {
-        return pixels[j*o_optimalSize.x+i];
+        return pixels[static_cast<long long>(j) * o_optimalSize.x + i];
     }
 }
 
@@ -312,7 +329,9 @@ bool CalculateOptimalROI::autocrop()
             };
             if(maxvalue>0)
             {
+#ifdef PRINT_DEBUG_VALUES
                 printf("Inner %d %ld: %d %d - %d %d\n", acc, maxvalue, m_bestRect.left(), m_bestRect.right(), m_bestRect.top(), m_bestRect.bottom());
+#endif
                 break;
             }
         }
@@ -330,7 +349,9 @@ bool CalculateOptimalROI::autocrop()
             };
             if (maxvalue>0)
             {
+#ifdef PRINT_DEBUG_VALUES
                 printf("Inner %d %ld: %d %d - %d %d\n", acc, maxvalue, m_bestRect.left(), m_bestRect.right(), m_bestRect.top(), m_bestRect.bottom());
+#endif
                 break;
             }
         }
@@ -338,7 +359,9 @@ bool CalculateOptimalROI::autocrop()
     
     for(int acc=startacc;acc>=1;acc/=2)
     {
+#ifdef PRINT_DEBUG_VALUES
         printf("Starting %d: %d %d - %d %d\n", acc, m_bestRect.left(), m_bestRect.right(), m_bestRect.top(), m_bestRect.bottom());
+#endif
         nonreccheck(m_bestRect, acc, 0, maxvalue);
         if (!getProgressDisplay()->updateDisplayValue())
         {
@@ -355,4 +378,44 @@ void CalculateOptimalROI::setStacks(std::vector<UIntSet> hdr_stacks)
     intersection=true;
 };
 
+// implementation of outside crop finding
+vigra::Rect2D CalculateOptimalROIOutside::getResultOptimalROI()
+{
+    if (hasRunSuccessfully())
+    {
+        return m_bestRect;
+    }
+    else
+    {
+        return vigra::Rect2D();
+    }
+}
+
+bool CalculateOptimalROIOutside::CalcOutsideCrop(PanoramaData& pano, AppBase::ProgressDisplay* progress)
+{
+    HuginBase::UIntSet activeImgs = pano.getActiveImages();
+    if (activeImgs.empty())
+    {
+        // no image, return false
+        return false;
+    };
+    HuginBase::PanoramaOptions opts = pano.getOptions();
+    // reset roi for calculation
+    opts.setROI(vigra::Rect2D(vigra::Point2D(0, 0), opts.getSize()));
+    m_bestRect = vigra::Rect2D();
+    progress->setMaximum(activeImgs.size());
+    for (auto& img : activeImgs)
+    {
+        // calculate boundary of all images, use a miniatur scale of 800 px for speed reasons
+        m_bestRect |= HuginBase::estimateOutputROI(pano, opts, img, 800);
+        progress->updateDisplayValue();
+        if (progress->wasCancelled())
+        {
+            m_bestRect = vigra::Rect2D();
+            return false;
+        };
+    };
+    return !m_bestRect.isEmpty();
+}
+
 } //namespace
