@@ -26,7 +26,22 @@
 #include <iostream>
 #include <iomanip>
 
+#include "hugin_config.h"
+#if defined HAVE_EPOXY && HAVE_EPOXY
+#ifdef _WIN32
+#define NOMINMAX
+#include <windows.h>
+#endif
+#include <epoxy/gl.h>
+#ifdef __APPLE__
+#include <OpenGL/glu.h>
+#include <GLUT/glut.h>
+#else
+#include <GL/glu.h>
+#endif
+#else
 #include <GL/glew.h>
+#endif
 
 #include <string.h>
 #ifdef _WIN32
