@@ -1212,22 +1212,9 @@ bool PanoDetector::FilterMatchesInPair(MatchData& ioMatchData, const PanoDetecto
 void PanoDetector::writeOutput()
 {
     // Write output pto file
-
-    std::ofstream aOut(_outputFile.c_str(), std::ios_base::trunc);
-    if( !aOut )
-    {
-        std::cerr << "ERROR : "
-             << "Couldn't open file '" << _outputFile << "'!" << std::endl; //STS
-        return;
-    }
-
-    aOut << "# pto project file generated by Hugin's cpfind" << std::endl << std::endl;
-
-    AppBase::DocumentData::ReadWriteError err = _panoramaInfo->writeData(aOut);
-    if (err != AppBase::DocumentData::SUCCESSFUL)
+    if(!_panoramaInfo->WritePTOFile(_outputFile, hugin_utils::getPathPrefix(_outputFile)))
     {
         std::cerr << "ERROR couldn't write to output file '" << _outputFile << "'!" << std::endl;
-        return;
     }
 }
 
