@@ -15,27 +15,23 @@
 *
 * You should have received a copy of the GNU General Public License
 * along with Panomatic; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+* <http://www.gnu.org/licenses/>.
 */
 
 #ifndef __Tracer_h
 #define __Tracer_h
 
 #include <iostream>
-#include "zthread/FastMutex.h"
-#include "zthread/Guard.h"
 
-static ZThread::FastMutex aIOMutex;
-
-#define TRACE_INFO(x) { ZThread::Guard<ZThread::FastMutex> g(aIOMutex); std::cout << x; }
+#define TRACE_INFO(x) { std::ostringstream buf; buf << x; std::cout << buf.str(); std::cout.flush();}
 
 #ifdef _DEBUG
-#define TRACE_DEBUG(x) { ZThread::Guard<ZThread::FastMutex> g(aIOMutex); std::cout << x; }
+#define TRACE_DEBUG(x) { std::ostringstream buf; buf << x; std::cout << buf.str(); std::cout.flush();}
 #else
 #define TRACE_DEBUG(x)
 #endif
 
-#define TRACE_ERROR(x) { ZThread::Guard<ZThread::FastMutex> g(aIOMutex); std::cerr << x; }
+#define TRACE_ERROR(x) { std::ostringstream buf; buf << x; std::cerr << buf.str(); std::cerr.flush(); }
 
 
 
