@@ -283,6 +283,13 @@ int main(int argc, char* argv[])
     double blueBalanceAnchor = 1.0;
     for(size_t i=0; i<filelist.size(); i++)
     {
+        const std::string ext = hugin_utils::getExtension(filelist[i]);
+        // check that extension does not belong to a raw file
+        if (hugin_utils::IsRawExtension(ext))
+        {
+            std::cerr << "Ignoring raw file " << filelist[i] << "." << std::endl;
+            continue;
+        };
         HuginBase::SrcPanoImage srcImage;
         std::cout << "Reading " << filelist[i] << "..." << std::endl;
         srcImage.setFilename(filelist[i]);
@@ -528,12 +535,11 @@ int main(int argc, char* argv[])
     };
     output = hugin_utils::GetAbsoluteFilename(output);
     //write output
-    HuginBase::UIntSet imgs;
-    fill_set(imgs,0, pano.getNrOfImages()-1);
-    std::ofstream of(output.c_str());
-    pano.printPanoramaScript(of, pano.getOptimizeVector(), pano.getOptions(), imgs, false, hugin_utils::getPathPrefix(output));
+    if (pano.WritePTOFile(output, hugin_utils::getPathPrefix(output)))
+    {
+        std::cout << std::endl << "Written output to " << output << std::endl;
+    };
 
-    std::cout << std::endl << "Written output to " << output << std::endl;
     HuginBase::LensDB::LensDB::Clean();
     return 0;
 }
